{% extends host_template %}

{% load i18n %}

{% block content %}

  {% for article in article_list %}
    {% include "articles/article_teaser.html" with current_object=article %}
  {% endfor %}

<!-- {include file="paginador.html" } -->

{% endblock %}
