{% extends "medialibrary/medialibrary_base_inline_detail.html" %}

{% block media_content %}
    {% with player_height='24' %}
    {% include 'medialibrary/media_player.html' %}
    {% endwith %}
{% endblock %}
