{% extends "medialibrary/medialibrary_base_detail.html" %}
{% load i18n %}

{% block media_content %}
  <br>
  <div style="width: 100%; height: 550px;">
    <object classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=10,0,0,0" width="100%" height="100%" id="curso-el-video" align="middle">
        <param name="allowScriptAccess" value="sameDomain" />
        <param name="allowFullScreen" value="true" />
        <param name="movie" value="{{ current_object.media_file }}" />
        <param name="quality" value="high" />
        <param name="base" value="{{ url_base }}" />
        <embed src="{{ current_object.media_file }}" quality="high" width="100%" height="100%" name="curso-el-video" align="middle" allowScriptAccess="sameDomain" allowFullScreen="false" type="application/x-shockwave-flash" pluginspage="http://www.adobe.com/go/getflashplayer_es" base="{{ url_base }}"/>
    </object>
  </div>
{% endblock %}

{% block media_content_download %}
    <div class="action-content download_link">
    <a target="_blank" href="{{ current_object.media_file }}">{% trans "full screen view (new window)" %}</a>
    </div>
{% endblock %}
