{% load i18n fb_versions cyclope_utils dbgettext_tags %}

{% block wholecontent %}
  {% block head %}
  <div class="content-view {{ current_object.get_object_name }} media">
    {% if view_options.show_title %}
      <h2 class="title">
      <a href="{% if current_object.skip_detail %}{{ current_object.content_url }}{% else %}{{ current_object.get_absolute_url }}{% endif%}" {% if current_object.new_window %}target="_blank"{% endif%} >
      {{ current_object.name }}
      </a></h2>
    {% endif %}
    {% if view_options.show_image and current_object.image %}
      <div class="teaser_icon_container media-content"><a href="{% if current_object.skip_detail %}{{ current_object.content_url }}{% else %} {{ current_object.get_absolute_url }}{% endif%}" {% if current_object.new_window %}target="_blank"{% endif%}>
        <img class="slideshow_picture" src="{% version current_object.image.path view_options.visualization_mode %}" alt="{{ current_object.name }}" /></a>
      </div>
    {% endif %}
  {% endblock head %}

  {% block description %}
    {% if view_options.show_description and current_object.description %}
      <div class="summary">{{ current_object.description|smart_style }}</div>
    {% endif %}
  {% endblock description %}
</div>
{% endblock wholecontent %}
