/*
# Cyclope 3 GPL
# Neutronix Workflow Design
# Layouts: 4 & 5 Elements
# Official Repository Cyclope 3 GPL: http://codigo.cyclope.ws
# Copyright 2010-2012 CodigoSur - SociedadCivil
# All rights reserved.
# This file is part of Cyclope 3.
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# Development: Codigo Sur www.codigosur.org
# Less CSS based www.lesscss.org
# 960 Grid System Based www.960.gs
# Neutronix is developed by Santiago Hoerth Moura
*/


/*-----------------------------------------------------------------------------------------------
FIRE
-----------------------------------------------------------------------------------------------*/
.five_elements .category_title .title {
  background:@color-alpha;
  display:block;
  color:@colorc;
  font-size:1em !important;
  border-top:1px solid @colorb;
  border-bottom:1px solid @colorb;
  padding:4px;}
  
.five_elements .category_title .title a {
  color:inherit;
  text-decoration:none;}
  
.five_elements .category_title .title a:hover {
  color:@colore;}
  
.five_elements #categories_navigation {
  padding:4px;
  display:block;
  float:right;
  font-weight:700;}
 
.five_elements #fire .category_title .title {
  display:none}
   
.five_elements #categories_navigation a {
  text-decoration:none;
  color:@colorb;}
  
.five_elements #categories_navigation a:hover {
  color:@colorc;}

.five_elements #fire {
  position:relative;
  border:none;
  background:none;
  padding:0 10px;
  margin:450px 0 0;}

.four_elements #fire {
  position:relative;
  border:none;
  background:none;
  padding:0 10px;
  margin:40px 0 0;}

  
#fire div.content_fire {
  margin:0 20px 0 10px;
  display:block;
  background:none;}
  
#neutrona-theme_staticpage_before_fire {
  padding:20px;
  background:@colord;
  margin:0 0 20px;
  color:@color-alpha;
  .rounded-corners(6px);}
  
#neutrona-theme_staticpage_before_fire a {
  color:@color-omega;}
  
#neutrona-theme_staticpage_before_fire a:hover {
  color:@color-alpha;} 
  
/*-----------------
TITLES
-------------------*/
/*general titles*/
#fire .title {
  display:block;
  margin:0 0 20px 0;
  font-size:2em;
  font-weight:700;}
  
/*teasers titles*/

#fire .labeled_icon .title {
  font-size:.8em;
  text-align:center;
  padding:3px;
  border:none;
  font-weight:400;}
  
/*forms titles*/
#fire form .title {
  color:@color-omega;
  font-weight:700;}

/*-----------------
DETAILS CONTENTS
-------------------*/
#fire .pretitle, #fire .date {
  color:@colord;
  text-transform:uppercase;
  display:inline;
  font-size:.7em;
  margin:5px 0 0;}

#fire .summary {
  color:@colore;
  font-weight:700;
  padding:10px 0;
  text-align:left;
  line-height:1.5em;
  font-size:1.2em;}

#fire .author {
  font-weight:700;
  color:@colord;
  border-left:4px solid @colorb;
  padding:0 0 0 10px;
  margin:10px 0 0;
  font-size:.9em;}

#fire .tags {
  margin:20px 0 0 ;
  display:block;}

#fire .source {
  color:@colore;
  font-size:.9em;
  margin:20px 0 0;
  display:block;}

#fire .more {
  font-size:inherit;
  font-weight:400;
  margin:0;
  padding: 0 0;
  display:inline;}

#fire .pagination  {
  font-size:0.65em;
  text-align:center;
  padding:3px;
  background:@colore;
  color:@colora;}

#fire .pagination a {
  color:@color-alpha;
  text-decoration:underline;}

#fire div.paginator {
  font-size:.7em;
  padding:5px;
  background:@colorc;
  color:@color-alpha;
  display:block;
  font-weight:700;
  text-align:center;
  margin:0 auto 10px;
  .rounded-corners(4px);}

#fire div.paginator a {
  color:@color-alpha;
  font-weight:400;
  text-decoration:underline;}

#fire div.paginator a:hover {
  color:@color-omega;}

#fire .staticpage-detail {
  border-bottom:3px solid @colorb;
  padding:0 0 10px;
  margin:0 0 10px;
  font-size:.8em;}

#fire .article-detail {
  }

#fire .article-detail a,#fire .staticpage-detail a {
  color:@color-omega;}

#fire .related_contents {
  font-weight:700;
  color:@colore;
  background:@colora;
  padding:10px;
  margin:0;
  width:60%;
 .rounded-corners(4px);}

#fire .related_contents span {
  font-size:1em;
  padding:0;
  margin:0;
  color:@colord;}

#fire .related_contents ul {
  padding:10px 0 0;
  margin:0;
  list-style:none;}

#fire .related_contents ul ul {
  list-style:square;}

#fire .related_contents li {
  color: @colorc;
  padding:0 10px 5px 0;
  margin:0 0 0 20px;}	

#fire .related_contents li a {
  font-size:0.8em;
  color:@colord;
  font-weight:400;}

#fire .related_contents li a:hover {
  color:@color-omega;
  font-weight:700;}

/*-----------------
LABELED ICONS
-------------------*/ 
#fire div.labeled_icon {
  height:180px;
  border:2px solid @colorc;
  background:@colora;
  display:block;
  width:130px;
  margin:	0 5px 10px;
  float:left;
  padding:5px;
  position:relative;
  .rounded-corners(8px);}

#fire .labeled_icon img.icon {
  height:130px;
  width:130px;}

#fire div.labeled_icon img.type_icon {
  position:absolute;
  top:10px;
  left:10px;}

#fire .labeled_icon_list {
  display:block;
  float:none;
  overflow:auto;
  margin:0 0 10px;
  padding:0 0 5px;
  border-bottom:3px solid @colorb;}

#fire .labeled_icon_list div.paginator {
  font-size:.7em;
  padding:5px;
  background:@colorc;
  color:@color-alpha;
  display:block;
  font-weight:700;
  text-align:center;
  margin:10px auto;
  .rounded-corners(4px);}

/*-----------------
TEASERS
-------------------*/ 
#fire .teaser {
  margin:0 0 25px;
  padding:0 0 20px;
  overflow:auto;
  border-bottom:1px dotted #ccc;}

#fire .teaser .title {
  border:none;
  margin:0;
  font-size:1.6em;
  color:@colord;}

#fire .teaser .title a {
  text-decoration:none;
  color:inherit;} 

#fire .teaser .title a:hover {
  text-decoration:underline;}

#fire .teaser .author {
  color:#999;
  border:none;
  padding:0;}
  
#fire .teaser .summary {
  color:@colord;
  font-weight:400;
  padding:5px 0 0;
  text-align:justify;
  line-height:1.3em;
  font-size:1em;}

#fire .teaser .summary p {
  display:inline;}

#fire .teaser .pretitle {
  margin:10px 0 0;
  display:inline-block;
  color:#333;} 

#fire .teaser .date {
  }
  
#fire .teaser img.teaser_icon {
  margin:5px 0 0 10px;
  padding:5px;
  .rounded-corners(8px);}

#fire .teaser img.icon {
  float:right;
  width:150px;
  clear:both;
  padding:3px;
  border:3px solid @colorb;
  margin:0 0 20px 20px;}

#fire .teaser img.type_icon {
  padding:0 0 0 10px;
  margin:0 0;
  float:right;}

#fire .teaser ul {
  color:@color-omega;
  font-size:1em;
  padding:15px 0;
  margin:0 0 0 30px;
  list-style:square;}

#fire .teaser li {
  margin:0 0 0 5px;
  padding:0 0 3px;}

#fire .teaser_list,
#fire .collection_all_items_teaser_list {
  margin:0 0 10px;
  border-bottom:3px solid @colorb;
  padding:0 0 10px;}

#fire div.collection_teaser {
  overflow:auto;
  background:@colora;
  display:block;
  margin:-20px 0 20px;
  padding:10px;
  border-bottom:1px solid @colord;}

#fire .staticpage-teaser {
  padding:0 0 10px;
  margin:0 0 10px;}

#fire .staticpage-teaser ul li h2 {
  font-size:.9em;
  margin:0 0 10px;}

#fire .staticpage-teaser ul {
  list-style:square;
  margin:0 15px;}

#fire .list_as_forum {
  border-bottom:3px solid @colorb;
  margin:0 0 10px;}    

#fire .categories ul {
  list-style:none;
  margin:10px 0;}

#fire .categories li {
  display:inline;
  border:1px solid @colorb;
  .rounded-corners(4px);
  padding:5px;
  background:@colora;
  color:@color-omega;
  margin:10px 10px 0 0;
  font-size:.75em;}

/*-----------------
HIERARCHY
-------------------*/
/*menu*/
#fire .menuitems_hierarchy{}
#fire .menuitems_hierarchy span {display:block;padding:0;margin:0;}
#fire .menuitems_hierarchy ul {margin:0  0 0 40px; padding:0; list-style:square;}
#fire .menuitems_hierarchy li {font-size:.8em;margin:4px 0;text-decoration:none;font-weight:700;border:none;background:none;padding:0;}
#fire .menuitems_hierarchy li a {text-decoration:none; color:@color-omega; }
#fire .menuitems_hierarchy li a:hover {text-decoration:underline;color:@colore;}
#fire .menuitems_hierarchy ul ul {margin:0 0 0 20px;padding:0;display:block;border:none;}
#fire .menuitems_hierarchy li li {padding:3px 0;margin:4px 0;border:none;border-bottom:none;}
#fire .menuitems_hierarchy li li a {color:@colord;display:block;border:none;background:none;}
#fire .menuitems_hierarchy li li a:hover {display:block;background:@color-alpha;color:@color-omega;text-decoration:none; }
#fire .menuitems_hierarchy ul ul ul {position:relative;left:170px;top:-21px;background:@colora;}
#fire .menuitems_hierarchy li li li {background:@colord;}
#fire .menuitems_hierarchy li li li a {color:@color-alpha;}
#fire .menuitems_hierarchy p {clear:left;}	
#fire .menuitems_hierarchy #current {background:url(images/current-bg.gif) top left repeat-x;color:@color-alpha;}
/*categories*/
#fire .categories_hierarchy,
#fire .categories_hierarchy_to_iconlist,
#fire .flat_items_list,
#fire .root_items_list,
#fire .menuitem,
#fire .menuitems_hierarchy {
  margin:0 0 10px;
  padding:0 0 10px;
  border-bottom:5px solid @colora;}

#fire .categories_hierarchy span,
#fire .categories_hierarchy_to_iconlist span,
#fire .flat_items_list span,
#fire .root_items_list span {
  display:block;
  padding:0;margin:0;}

#fire .categories_hierarchy ul,
#fire .categories_hierarchy_to_iconlist ul,
#fire .flat_items_list ul,
#fire .root_items_list ul,
#fire .menuitem ul,
#fire .category_root_item_list ul {
  margin:0 0 0 40px;
  padding:0;
  list-style:square;
  display:block;}

#fire .categories_hierarchy li,
#fire .categories_hierarchy_to_iconlist li,
#fire .flat_items_list li,
#fire .root_items_list li,
#fire .menuitem li,
#fire .category_root_item_list li {
  font-size:.8em;
  margin:4px 0;
  text-decoration:none;
  font-weight:700;
  border:none;
  padding:0 10px 8px;}

#fire .categories_hierarchy li a,
#fire .categories_hierarchy_to_iconlist li a,
#fire .flat_items_list li a,
#fire .root_items_list li a,
#fire .menuitem li a,
#fire .category_root_item_list li a {
  text-decoration:none;
  color:@color-omega;
  display:block;}

#fire .categories_hierarchy li a:hover,
#fire .categories_hierarchy_to_iconlist li a:hover,
#fire .flat_items_list li a:hover,
#fire .root_items_list li a:hover,
#fire .menuitem li a:hover,
#fire .category_root_item_list a:hover {
  text-decoration:underline;
  color:@colore;}

#fire .categories_hierarchy ul ul,
#fire .categories_hierarchy_to_iconlist ul ul,
#fire .flat_items_list ul ul,
#fire .root_items_list ul ul,
#fire .menuitem ul ul,
#fire .category_root_item_list ul ul {
  margin:0;
  padding:0;
  display:block;
  border:none;}
  
#fire .categories_hierarchy li li,
#fire .categories_hierarchy_to_iconlist li li,
#fire .flat_items_list li li,
#fire .root_items_list li li,
#fire .menuitem li li,
#fire .category_root_item_list li li {
  display:block;
  padding:3px 0;
  margin:4px 0;
  border:none;
  border-bottom:1px solid @colorb;}

#fire .categories_hierarchy li li a,
#fire .categories_hierarchy_to_iconlist li li a,
#fire .flat_items_list li li a,
#fire .root_items_list li li a,
#fire .menuitem li li a,
#fire .category_root_item_list li li a {
  color:@colord;
  display:block;
  border:none;
  background:none;}

#fire .categories_hierarchy li li a:hover,
#fire .categories_hierarchy_to_iconlist li li a:hover,
#fire .flat_items_list li li a:hover,
#fire .root_items_list li li a:hover,
#fire .menuitem li li a:hover,
#fire .category_root_item_list li li a:hover {
  display:block;
  background:@color-alpha;
  color:@color-omega;
  text-decoration:none;}

#fire .categories_hierarchy ul ul ul,
#fire .categories_hierarchy_to_iconlist ul ul ul,
#fire .flat_items_list ul ul ul,
#fire .root_items_list ul ul ul,
#fire .menuitem ul ul ul,
#fire .category_root_item_list ul ul ul {
  position:relative;
  left:170px;
  top:-21px;
  background:@colora;}

#fire .categories_hierarchy li li li,
#fire .categories_hierarchy_to_iconlist li li li,
#fire .flat_items_list li li li,
#fire .root_items_list li li li,
#fire .menuitem li li li,
#fire .category_root_item_list li li li {
  background:@colord;}

#fire .categories_hierarchy li li li a,
#fire .categories_hierarchy_to_iconlist li li li a,
#fire .flat_items_list li li li a,
#fire .root_items_list li li li a,
#fire .menuitem li li li a,
#fire .category_root_item_list li li li a {
  color:@color-alpha;}

/*-----------------
CONTACTS
-------------------*/
#fire .contact-teaser .title {
  margin:0 0 10px 0;
  color:@color-omega;
  font-weight:700;
  font-size:1.5em;
  padding:0;
  background:none;
  border:none;}

#fire .contact-teaser .title a {
  text-decoration:none;
  color:@color-omega;
  display:block;}

#fire .contact-teaser .title a:hover {
  text-decoration:underline;
  color:@colorc;}

#fire .contact-teaser .title img.photo {
  width:130px;
  padding:5px;
  background:@colora;
  border:1px solid @colore;
  float:none;
  margin:0 0 10px;}

#fire .contact-teaser {
  border-bottom:none;
  padding:5px 0;
  margin:0 0 10px;}

#fire .contact-teaser img.type_icon {
  display:none;}

#fire .contact-teaser .contact-details {
  clear:left;}

#fire .contact-teaser .contact-details .more {
  display:block;}

#fire .details-list {
  display:inline;}

#fire .detail img.contact_photo {
  width:166px;
  float:left;
  padding:5px;
  border:2px solid @colorc;
  .rounded-corners(4px);}

#fire .contact_teaser_detail{
  position:absolute;
  left:200px;
  font-size:1.1em;}

#fire .contact_teaser_detail div {
  padding:0 0 10px;}

#fire .contact_teaser_detail div span {
  font-weight:700;}

#fire .details-list {
  }

#fire .detail {
  position:relative;}

#fire .contact-detail .tools ul {
  margin:0 0 30px;
  display:block;}

#fire .contact-detail .categories ul {
  margin:0;
  padding:0;}

#fire .teaser_list div.paginator {
  font-size:.8em;
  padding:5px 0;
  background:none;
  color:@color-omega;
  display:block;
  font-weight:700;
  text-align:left;
  margin:0 auto 10px;}

#fire .teaser_list div.paginator a {
  color:@color-omega;
  font-weight:400;
  text-decoration:underline;}

#fire .teaser_list div.paginator a:hover {
  color:@colorc;}

/*-----------------
FORMS
-------------------*/
#fire form small {
  font-size:0.7em;
  padding:5px 0;
  display:block;}

#fire form input {
  padding:2px;
  width:130px;
  .rounded-corners(3px);
  background:@color-alpha;
  color:@color-omega;
  border:1px solid @color-omega;}

#fire form input.submit {
  width:30px;
  background:@colord;
  color:@color-alpha;
  border:1px solid @color-omega;}

/*-----------------
SEARCH BOX
-------------------*/
#fire .search-box {
  overflow:auto;}

#fire .search-box form {
  margin:0 0;
  padding:5px;}

#fire .search-box input {
  padding:5px 3px;
  margin:0 0 1px 0;
  border:1px solid @color-omega;
  color:@color-omega;
  width:350px;
  background:@color-alpha;
  font-size:0.75em}

#fire .search-box input.submit {
  border:none;
  padding:3px 0;
  margin:0 0 0 0;
  width:25px;
  height:25px;
  background:url(../images/css/btn.png) no-repeat;}

/*-----------------
TEXTILE FORMAT
-------------------*/

#fire pre {
  max-width:700px;
  overflow-x:auto;
  overflow-y:auto;
  .rounded-corners(4px);
  margin:10px 0;
  padding:20px;
  border:1px solid @colorb;
  background:@colora;
  font-size:0.9em;
  font-weight:400;
  color:@color-omega;}

#fire code {
  padding:0;
  color:@colorc;
  font-weight:400;
  overflow:scroll;}

#fire div.text p {
  font-size:1em;
  line-height:1.5em;
  text-align:left;
  padding:20px 0 0;}

#fire span {
  margin:inherit;
  padding:inherit;}

#fire span.tip {
  margin:-20px 0 0;
  padding:20px;
  display:block;
  text-align:left;
  width:60%;
  color:@color-alpha;
  background:@colorc;
  border-left:5px solid @color-omega;
  font-size:0.9em;}

#fire blockquote {
  background:@colora;
  padding:0 20px 20px;
  margin:10px 0;
  font-size:0.9em;
  width:60%;
  line-height:1em;
  border-left:5px solid @colorb;
  text-align:left;}

#fire sup {
  }

#fire sub {
  }

#fire cite {
  }

#fire ul {
  color:@color-omega;
  font-size:1.1em;
  line-height:1.5em;
  padding:15px 0;
  margin:0 0 0 30px;
  list-style:square;}

#fire ol {
  color:@color-omega;
  font-size:1.1em;
  line-height:1.5em;
  padding:15px 0;
  margin:0 0 0 30px;}   

#fire li {
  margin:0 0 0 5px;
  padding:0 0 3px;}

#fire acronym /*acronym textile are broken (bug cyclope, django or textile?)*/{
  }

#fire del {
  }

#fire ins {
  } 

#fire .text table {
  margin:20px auto;
  color:@colore;
  padding:0;
  border:none;}

#fire .text th {
  background:@colord;
  color:@color-alpha;
  border:1px solid @color-omega;
  margin:0;
  padding:3px;}

#fire .text tr {
  margin:0;
  padding:0;}

#fire .text td {
  margin:0;
  padding:3px;
  border:1px solid @colorb;}

#fire img {
  }

#fire div.text p.footnote, .staticpage-detail div.text p.footnote {
  color:@colord;
  font-size:.8em;
  margin:4px 0;
  padding:0;}

#fire .text {
  padding:0 0 20px;}

#fire .text ul {
  padding:0;
  margin:0 0 0 30px;
  list-style:square;}

#fire .text li {
  padding:15px 0 0;}

#fire #container .content-view img {
  margin:20px 0 20px 20px;
  padding:0;
  float:none;
  .shadows(2px 2px 20px #666);}

#fire #container .content-view h1 {
  color:@color-omega;
  padding:10px 0;
  margin:30px 0 30px;
  border-bottom:1px solid @color-omega;
  display:block;}

/*tags*/
#fire .tags {
  margin:0;
  padding:10px 0 0;
  font-size:0.7em;
  display:block;} 

#fire .tags a {
  color: @colord}

#fire .tags a:hover {
  color:@color-omega;
  text-decoration:underline;}

#fire .tools {
  margin:10px 0;
  padding:0 0;}

#fire .tools ul {
  text-align:left;
  margin:0;
  padding:0;
  list-style:none;
  font-weight:bold;
  font-size:0.8em;}

#fire .tools ul a:hover {
  text-decoration:underline;} 

#fire .tools li {
  display:inline;}

#fire .tools li .print {
  color: @colorc;
  background: transparent url(../images/css/imprimir.png) left top no-repeat;
  padding:0 0 10px 20px;
  margin:0;}

#fire .tools li .share {
  color: @colorc;
  background: transparent url(../images/css/recomendar.png) no-repeat;
  padding:0 0 10px 20px;
  margin:0 0 0 15px;}

#fire .tools li .comments_link {
  color: @colorc;
  background: transparent url(../images/css/comentarios.png) no-repeat;
  padding:0 0 10px 20px;
  margin:0 0 0 15px;}

#spark {
  display:block;
  clear:both;
  padding:15px 0px 0 0;
  position:absolute;  
  margin:30px auto 0;
  background:url(../images/css/bordersB.png) no-repeat top right;
  height:100px;}

#spark .slodeshow {  
  margin:0 auto;
  background:#facd34;
  padding:0 20px 0 0;
  width:960px;
  display:block;
  clear:both;
  overflow:auto; 
  right:-20px;}
