{% extends CYCLOPE_DEFAULT_TEMPLATE %}
{% load i18n crispy_forms_tags %}

{% block content%}
<div class="frontend_login">
<h1 class="title">{% trans "Registration" %}</h1>
<div class="form_summary">
    <div class="summary">
      <p>{% trans "Please fill in your user profile data" %}</p>
    </div>
</div>
{% crispy form %}
</div>
{% endblock %}
