{% extends CYCLOPE_DEFAULT_TEMPLATE %}
{% load i18n cyclope_utils crispy_forms_tags %}

{% block content%}
<div id="contact" class="user_input">
{{ instructions|smart_style }}
{% crispy form %}
</div>
{% endblock %}
