{% extends CYCLOPE_DEFAULT_TEMPLATE %}
{% load i18n %}

{% block content%}

{% for profile in object_list %}
<a href="/profiles/{{ profile.user.username }}/?next={{request.path}}">{{ profile.user.username }}</a>
{% endfor %}
<br/>
<a href="{{request.META.HTTP_REFERER}}">{% trans "Return" %}</a>

{% endblock %}
