{% extends CYCLOPE_DEFAULT_TEMPLATE %}
{% load i18n %}

{% block title %}{% trans "Thanks for commenting" %}.{% endblock %}

{% block content %}
<script type="text/javascript">
  setTimeout('window.location = "{{ comment.content_object.get_absolute_url }}"', 3000);
</script>

<h2>{% trans "Thank you for your comment" %}.</h2>
<p><a href="{{ comment.content_object.get_absolute_url }}">{% trans "return." %}</a></p>

{% endblock %}
