{% extends "admin/base_site.html" %}
{% load i18n %}

{% block content %}
<h2>
  {% trans "The e-mail for newsletter" %} {{ newsletter.name }}
  {% trans "could not be sent." %}
  <br/>
  {% trans "You should try again later or contact your administrator." %}
</h2>
<p><a href="/admin/newsletter/newsletter/{{ newsletter.id }}">{% trans "Return to newsletter admin" %}</a></p>

{% endblock %}
