{% extends host_template %}

{% load comments i18n fb_versions cyclope_utils markup crispy_forms_tags %}

{% block content %}

{% alias poll as 'current_object' %}

<div class="content-view poll submission poll-submission">

  <div class="meta-content">{% include 'collections/categories_navigation_block.html' %}</div>

  <h1 class="title">{{ poll.name }}</h1>

  <form action="{% url poll-submission poll.slug %}" method="POST" class="uniForm">
    {% csrf_token %}
    {% for form in forms %}
        {{ form|crispy }}
    {% endfor %}
    {{ captcha_form|crispy }}
    <div class="buttonHolder">
      <input type="submit" value="{% trans "Submit" %}" />
    </div>
  </form>

</div>

{% endblock content%}
