/*
# Cyclope 3 GPL
# Neutronix Workflow Design
# Layouts: 4 & 5 Elements
# Official Repository Cyclope 3 GPL: http://codigo.cyclope.ws
# Copyright 2010-2012 CodigoSur - SociedadCivil
# All rights reserved.
# This file is part of Cyclope 3.
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# Development: Codigo Sur www.codigosur.org
# Less CSS based www.lesscss.org
# 960 Grid System Based www.960.gs
# Neutronix is developed by Santiago Hoerth Moura
*/

/*-----------------------------------------------------------------------------------------------
EARTH
-----------------------------------------------------------------------------------------------*/
#footer_separator { 
  clear:both;
  height:0;}
  
.footer_global {
  color:@colorc;
  text-align:center;
  padding:10px 0;
  margin:0;
  border-bottom:2px solid #ccc;
  border-top:1px solid #ccc;
  margin:0;
  background-color:#f8f8f8;
  .rounded-corners(0);}

.footer_global  a {
  color:@colord;
  text-decoration:underline;}

.footer_global  a:hover {
  color:@colorc;
  text-decoration:none;}

.footer_global  img {
  padding:10px 0 0;}

.footer_global  span {
  font-size:.75em;}

#earth {
  font-size:.85em !important;
  font-weight:700;
  margin:0 0 10px;}

#earth  a {
  color:@colora; 
  text-decoration:underline;}

#earth  a:hover {
  color:@colorc; 
  text-decoration:none;}

#earth  img {
  padding:10px 0 0;}

#logos {
  text-align:center;
  font-size: 0.7em;
  padding:1px 0 20px 0;
  margin:10px auto;}

#logos img {
  padding:7px 0 0;}

.expand_collapse{
  font-weight:bold;
  clear:none;
  margin:0px;
  padding:0px;
  color:black;
  float:left;
  margin:0 4px 0 4px;
  cursor: pointer;}
