{% extends "medialibrary/medialibrary_base_detail.html" %}
{% load i18n %}

{% block media_content_download %}
  <div class="action-content download_link">
    <a href="{{ current_object.content_url }}" {% if current_object.new_window %}target="_blank"{% endif %}>
    {% trans "Open external content"%} {% if media.new_window %}{% trans " (in new window)"%}{% endif %}
    </a>
  </div>
{% endblock %}
