{% load i18n fb_versions cyclope_utils dbgettext_tags %}

  <div class="article content-view">

    {% if view_options.show_title %}
    <h2 class="title"><a href="{% url article-detail article.slug %}">{{ article.name|truncatechars:70 }}</a></h2>
    {% endif %}

    {% if view_options.show_image %}
    <div class="teaser_icon_container">
          <img title="article" class="type_icon" src="{{ CYCLOPE_THEME_MEDIA_URL }}images/icons/article.png" border="0"/>
    <a href="{% url article-detail article.slug %}">
        {% if article.pictures %}
            {% if not view_options.show_title and not view_options.show_description %}
          <img class="icon big" src="{% version article.pictures.0.image.path 'big' %}" border="0"/>
            {% else %}
          <img class="slideshow_picture" src="{% version article.pictures.0.image.path view_options.visualization_mode %}" border="0"/>
            {% endif %}
        {% else %}
          <img class="icon" src="{{ CYCLOPE_THEME_MEDIA_URL }}images/icons/not-available.png" border="0"/>
        {% endif %}
    </a>
    </div>
    {% endif %}

    {% if view_options.show_description %}
      <div class="html-content summary">
      {% if article.summary %}
      {{ article|parsed_gettext:"summary"|smart_style }}
      {% else %}
      {{ article|parsed_gettext:"text"|smart_style|truncatewords_html:40 }}
      {% endif %}
      </div>
    {% endif %}
