{% extends "cyclope/themes/neutronix/base.html" %}

{% block neutronixcss %}
    <link href="{{ CYCLOPE_STATIC_URL }}themes/neutronix/css/neutronix.less" rel="stylesheet{% if not COMPRESS_ENABLED %}/less{% endif %}" type="text/less"/>
    <link href="{{ CYCLOPE_THEME_MEDIA_URL }}css/cyclope.less" rel="stylesheet{% if not COMPRESS_ENABLED %}/less{% endif %}" type="text/less"/>
{% endblock %}
