{% extends host_template %}

{% load i18n comments cyclope_utils fb_versions %}

{% block content %}

<div class="content-view {{ current_object.get_object_name }} media detail">

<h1 class="title">{{ current_object.name }}</h1>

{% include 'cyclope/content_tools_block.html' %}

{% include "cyclope/author_block.html" with author=current_object.author %}

{% if current_object.image %}
  <div class="media-content">
    {% if current_object.content_url %}<a href="{{ current_object.content_url }}" {% if current_object.new_window %}target="_blank"{% endif%} >{% endif%}
    <img align="center" src="{% version current_object.image.path 'big' %}"/>
    {% if current_object.content_url %}</a>{% endif%}
  </div>
{% endif %}

{% block media_content %}
{% endblock %}

{% block media_content_download %}
<div class="action-content download_link">
    <a target="_blank" href="{{ current_object.media_file }}">{% trans "download file" %}</a>
</div>
{% endblock %}

<div class="html-content summary">{{ current_object.description|smart_style }}</div>

{% if current_object.get_last_change_date or current_object.source %}
  <div class="meta-content">
    {% if current_object.get_last_change_date %}
      <h6 class="date">{% trans "Last modification date" %}: {{ current_object.get_last_change_date }}</h6>
    {% endif %}

    {% include "cyclope/source_block.html" with source=current_object.source %}
  </div>
{% endif %}

<div class="meta-content">{% include 'collections/categories_navigation_block.html' %}</div>

{% include 'cyclope/related_contents_block.html' %}

{% include 'ratings/rating_block.html' %}

{% block media_comments %}
    {% include 'comments/comments_block.html' %}
{% endblock %}

</div> <!--end media_detail -->
{% endblock content%}
