{% extends host_template %}

{% load i18n cyclope_utils fb_versions %}

{% block content %}

  {% include 'collections/collection_info.html' %}

  {% include 'cyclope/alphabetical_pagination_block.html' %}

  {% comment %}
  We show a teaser view of every object belonging to this collection.
  {% endcomment %}

  {% for object in object_list %}
    {% join object.get_app_label  "/" object.get_object_name "_teaser.html" as template_path %}

    {% comment %}
      we alias the actual object with the model name
      so the included template is reusable
      and can access the content object using an explicit name
    {% endcomment %}

    {% alias object as object.get_object_name %}
    {% include template_path %}
  {% endfor %}

{% endblock %}
