{% extends host_template %}

{% load i18n cyclope_utils fb_versions dbgettext_tags %}

{% block content %}

  {% for categorization in categorizations %}
    {% alias categorization.content_object as 'article' %}
<div class="teaser">
<table>
  <tr>
    <td>
      {% if newsletter.show_ToC %}<div class="show-ToC"><a href="#ToC">{% trans "Return to Table of Contents" %}</a></div>{% endif %}
      <div class="clear"></div>
      {% if article.pictures %}
      <a href="{% url article-detail article.slug %}">
        <img class="newsletter_image" src="{% version article.pictures.0.image.path 'thumbnail' %}" alt="{{ article.pictures.0.name }}"/>
      </a>
      {% endif %}
      {% if article.pretitle %} <span class="pretitle"><a name="editorial">{% trans article.pretitle %}</a></span>{% endif %}
      <a name="article__{{ article.slug }}" href="{% url article-detail article.slug %}">
        <h2 class="title">{% trans article.name  %}</h2>
      </a>


      <a href="{% url article-detail article.slug %}">
        <div class="summary">{{ article|parsed_gettext:"summary"|smart_style }}</div>
      </a>
      {% if article.author %}
      <h4 class="author">{% trans "By"%} {{ article.author }}</h4>
      {% endif %}


    </td>
  </tr>
</table>
</div>

  {% endfor %}

{% endblock %}
