/*
# Cyclope 3 GPL
# Neutronix Workflow Design
# Layouts: 4 & 5 Elements
# Copyright 2010-2012 CodigoSur - SociedadCivil
# All rights reserved.
# This file is part of Cyclope 3.
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# Development: Codigo Sur www.codigosur.org
# Less CSS based www.lesscss.org
# 960 Grid System Based www.960.gs
# Neutronix is developed by Santiago Hoerth Moura
*/

/*-----------------------------------------------------------------------------------------------
WATER 
-----------------------------------------------------------------------------------------------*/
#water {
  position:relative;
  padding:0;
  margin:0;
  .rounded-corners(6px);}
#water .content-view {}
#water .more {
  font-size:inherit;
  font-weight:400;
  margin:0; 
  padding: 0 0;
  display:inline;}
  
#water .pagination  {
  font-size:0.65em;
  text-align:center;
  padding:3px;
  background:@colore;
  color:@colora;}

#water .pagination a {
  color:@color-alpha;
  text-decoration:underline;}
  
#water .author {
  font-size:0.8em;
  font-weight:700;
  margin:10px 0 0;
  color:@colord;
  padding:0 0 0 10px;}
  
#water .teaser {
  margin:0 0 10px;
  padding:0 0 10px;
  overflow:auto;}

#water .teaser .title {
  margin:0 0 10px 0;
  color:@color-alpha;
  background:@colorc;
  position:relative;
  overflow:auto;
  font-size:.8em;
  padding:7px 3px 7px 26px;
  border-bottom:none;
  .rounded-corners(6px);}

#water .teaser .title a {
  text-decoration:none;
  color:inherit;}

#water .teaser .title a:hover {
  text-decoration:underline;
  color:@color-omega;}  
  
#water .teaser .tile img {
}

#water .teaser img.teaser_icon {
  float:left;
  width:60px;
  padding:0;
  border:1px solid @color-omega;
  background:@color-alpha;
  margin:3px 5px 0 0;}
  
#water .teaser .pretitle, #water .teaser .date {
  margin:0 0 5px;
  font-size:0.6em;
  display:inline;
  text-align:right;
  text-transform:none;
  color:@color-omega;
  padding:0 0 5px 5px;
  .rounded-corners(4px);}
  
#water .teaser .date {
  padding:0;}

#water .teaser img.icon {
  float:right;
  width:150px;
  clear:both;
  padding:3px;
  border:3px solid @colorb;
  margin:0 0 20px 20px;}
  
#water .teaser img.type_icon {
  width:20px;
  padding:0;
  margin:0 0;
  position:absolute;
  left:3px;top:5px;}
  
#water .teaser .summary {
  color:@colore;
  font-weight:400;
  padding:0;
  text-align:left;
  line-height:1.2em;
  font-size:.8em;
  margin:-3px 0 5px;}
  
#water .teaser .summary p {
  display:inline;}
  
#water .teaser ul {
  color:@color-omega;
  font-size:1em;
  padding:15px 0;
  margin:0 0 0 30px;
  list-style:square;}
  
#water .teaser li {
  margin:0 0 0 5px;
  padding:0 0 3px;}
  
#water .category_title .title {
  padding:10px 0;
  margin:0 0 10px;
  display:block;
  border-bottom:none;
  font-size:1em;
  text-align:center;
  background:@colore;
  color:@color-alpha;
  .rounded-corners(6px);}
  
#water .category_title .title a {
  color:@color-alpha;}
  
#water .staticpage-teaser {
  border-bottom:3px solid @colorb;
  padding:0 0 10px;
  margin:0 0 10px;}
  
#water .staticpage-teaser ul li h2 {
  font-size:.9em;
  margin:0 0 10px;}
  
#water .staticpage-teaser ul  {
  list-style:square;
  margin:0 15px;}
  
#water .staticpage-detail {
  border-bottom:3px solid @colorb;
  padding:0 0 10px;
  margin:0 0 10px;
  font-size:.8em;}

#water .categories_hierarchy .title,
#water .categories_hierarchy_to_iconlist .title,
#water .flat_items_list .title,
#water .root_items_list .title,
#water .menuitem .title,
#water .menuitems_hierarchy .title {
  font-weight:700;
  padding:10px 0;
  margin:0 0 5px;
  display:block;
  border-bottom:none;
  font-size:.85em;
  text-align:center;
  background:@colore;
  color:@color-alpha;
  .rounded-corners(6px);}
  
#water .categories_hierarchy .title a,
#water .categories_hierarchy_to_iconlist .title a,
#water .flat_items_list .title a,
#water .root_items_list .title a,
#water .menuitem .title a,
#water .menuitems_hierarchy .title a {
  color:@color-alpha;}

#water .menuitems_hierarchy #current {
  background:url(images/current-bg.gif) top left repeat-x;
  color:@color-alpha;}
  
#water .menuitems_hierarchy, 
#water .categories_hierarchy,
#water .categories_hierarchy_to_iconlist,
#water .flat_items_list,
#water .root_items_list,
#water .menuitem,
#water .menuitems_hierarchy {
  margin:0 0 10px;
  padding:0 0 10px;
  border-bottom:none}
  
#water .menuitems_hierarchy span,
#water .categories_hierarchy  span,
#water .categories_hierarchy_to_iconlist span,
#water .flat_items_list span,
#water .root_items_list span  {
  }

#water .menuitems_hierarchy ul,
#water .categories_hierarchy ul,
#water .categories_hierarchy_to_iconlist ul,
#water .flat_items_list ul,
#water .root_items_list ul,
#water .menuitem ul,
#water .category_root_item_list ul {
  margin:0 ; 
  padding:0; 
  list-style:none;
  display:block;}
  
#water .menuitems_hierarchy li,
#water .categories_hierarchy li,
#water .categories_hierarchy_to_iconlist li,
#water .flat_items_list li,
#water .root_items_list li,
#water .menuitem li
#water .category_root_item_list li {
  font-size:.8em;
  margin:4px 0;
  text-decoration:none;
  font-weight:700;
  border:none;
  background:@colord;
  padding:8px 10px;
  .rounded-corners(6px);}
  
#water .menuitems_hierarchy li:hover,
#water .categories_hierarchy li:hover,
#water .categories_hierarchy_to_iconlist li:hover,
#water .flat_items_list li:hover,
#water .root_items_list li:hover,
#water .menuitem li:hover,
#water .category_root_item_list li:hover {
  background:@colore;}

#water .menuitems_hierarchy li a,
#water .categories_hierarchy li a,
#water .categories_hierarchy_to_iconlist li a,
#water .flat_items_list li a,
#water .root_items_list li a,
#water .menuitem li a,
#water .category_root_item_list li a {
  text-decoration:none;
  color:@color-alpha;
  display:block;}

#water .menuitems_hierarchy li a:hover,
#water .categories_hierarchy li a:hover,
#water .categories_hierarchy_to_iconlist li a:hover,
#water .flat_items_list li a:hover,
#water .root_items_list li a:hover,
#water .menuitem li a:hover,
#water .category_root_item_list li a:hover {
  text-decoration:underline;
  color:@colorb;}

#water .menuitems_hierarchy ul ul ,
#water .categories_hierarchy ul ul,
#water .categories_hierarchy_to_iconlist ul ul,
#water .flat_items_list ul ul,
#water .root_items_list ul ul,
#water .menuitem ul ul,
#water .category_root_item_list ul ul {
  margin:0;
  padding:0;
  display:block;
  border:none;}

#water .menuitems_hierarchy li li,
#water .categories_hierarchy li li,
#water .categories_hierarchy_to_iconlist li li,
#water .flat_items_list li li,
#water .root_items_list li li,
#water .menuitem li li,
#water .category_root_item_list li li {
  font-size:1em;
  display:block;
  padding:3px 3px;
  margin:4px 0;
  border:none;
  border-bottom:1px dotted @colorb;
  background:transparent;
  .rounded-corners(0);}

#water .menuitems_hierarchy li li:hover {
  background:transparent;}

li li:hover a {
  color:@color-omega;}

#water .menuitems_hierarchy li li a,
#water .categories_hierarchy li li a,
#water .categories_hierarchy_to_iconlist li li a,
#water .flat_items_list li li a,
#water .root_items_list li li a,
#water .menuitem li li a,
#water .category_root_item_list li li a {
  color:@color-alpha;
  display:block;
  border:none;
  background:none;}
  
#water .categories_hierarchy li li a:hover,
#water .categories_hierarchy_to_iconlist li li a:hover,
#water .flat_items_list li li a:hover,
#water .root_items_list li li a:hover,
#water .menuitem li li a:hover,
#water .category_root_item_list li li a:hover {
  display:block;
  background:@color-alpha;
  color:@color-omega;
  text-decoration:none;}

#water .menuitems_hierarchy ul ul ul ,
#water .categories_hierarchy ul ul ul,
#water .categories_hierarchy_to_iconlist ul ul ul,
#water .flat_items_list ul ul ul,
#water .root_items_list ul ul ul,
#water .menuitem ul ul ul,
#water .category_root_item_list ul ul ul {
  position:relative;
  left:0;
  top:0;
  background:transparent;}
  
#water .menuitems_hierarchy li li li , 
#water .categories_hierarchy li li li,
#water .categories_hierarchy_to_iconlist li li li,
#water .flat_items_list li li li,
#water .root_items_list li li li,
#water .menuitem li li li,
#water .category_root_item_list li li li {
  background:transparent;
  border:none;}

#water .menuitems_hierarchy li li li a,
#water .categories_hierarchy li li li a,
#water .categories_hierarchy_to_iconlist li li li a,
#water .flat_items_list li li li a,
#water .root_items_list li li li a,
#water .menuitem li li li a,
#water .category_root_item_list li li li a {
  color:@color-alpha;}

#water .menuitems_hierarchy p {
  clear:left;}
  	
#water .menuitems_hierarchy span.current a {
  }

#water .collection_header .title {
  padding:10px 0;
  margin:0 0 5px;
  display:block;
  border-bottom:none;
  font-size:1em;
  text-align:center;
  background:@colore;
  color:@color-alpha;
  .rounded-corners(6px);}

#water .collection_teaser {
  margin:0 0 10px;
  border-bottom:1px solid @color-omega;
  padding:0 0 10px;}

#water .collection_teaser .summary {
  color:@colore;
  font-weight:700;
  padding:0;
  text-align:left;
  line-height:1.5em;
  font-size:.8em;}
  
#water .collection_teaser .summary p {
  display:block;}
  
#water .collection_teaser img.image {
  float:none;
  width:170px;
  margin:0;
  padding:0;}
  
#water .labeled_icon .title {
  font-size:.55em;
  text-align:center;
  padding:1px;
  border:none;
  font-weight:400;}
  
#water .labeled_icon img.icon {
  height:60px;
  width:60px;}
  
#water div.labeled_icon {
  width:60px;
  height:110px;
  border:2px solid @colorc;
  background:@colora;
  display:block;
  margin:0 5px 5px ;
  float:left;
  padding:5px 5px ;
  position:relative;
  .rounded-corners(8px);}
  
#water div.labeled_icon img.type_icon {
  width:12px;
  position:absolute;
  top:10px;
  left:10px;}
  
#water .labeled_icon_list {
  display:block;
  float:none;
  overflow:auto;
  margin:0 0 10px;
  padding:0 0 5px;
  border-bottom:3px solid @colorb;}

#water .icon_list_container {
  margin:0 0 5px;
  overflow:auto;}
  
#water div.paginator {
  font-size:.7em;
  padding:5px;
  background:@colorc;
  color:@color-alpha;
  display:block;
  font-weight:700;
  text-align:center;
  margin:0 auto 10px;
  .rounded-corners(4px);}

#water div.paginator a {
  color:@color-alpha;
  font-weight:400;
  text-decoration:underline;}

#water div.paginator a:hover {
  color:@color-omega;}

#water .teaser_list,
#water .collection_all_items_teaser_list {
  margin:0 0 10px;
  border-bottom:3px solid @colorb;
  padding:0 0 10px;}

#water .contact-teaser {
  border-bottom:1px solid @colorc;
  padding:5px 0;
  margin:0;}

#water .contact-teaser img.type_icon {
  display:none;}

#water .contact-teaser .title {
  display:inline;
  margin:0 0 10px 0;
  color:@color-omega;
  font-weight:700;
  font-size:.9em;
  padding:0;
  background:none;
  border:none;}

#water .contact-teaser .title a {
  text-decoration:none;
  color:@color-omega;
  display:inline;}

#water .contact-teaser .title a:hover {
  text-decoration:underline;
  color:@colorc;}

#water .contact-teaser .title img.photo {
  width:30px;
  float:left;
  padding:0 5px 0 0;}

#water .contact-teaser .contact-details {
  display:none;}

#water form .title {
  color:@color-omega;
  font-weight:700;}

#water form small {
  font-size:0.7em;
  padding:5px 0;
  display:block;}

#water form input {
  padding:2px;
  width:130px;
  .rounded-corners(3px);
  background:@color-alpha;
  color:@color-omega;
  border:1px solid @color-omega;}

#water form input.submit {
  width:30px;
  background:@colord;
  color:@color-alpha;
  border:1px solid @color-omega;}

#water .tags {
  margin:0;
  padding:10px 0 0;
  font-size:0.7em;
  display:block;} 

#water .tags a {
  color: @colord}

#water .tags a:hover {
  color:@color-omega; 
  text-decoration:underline;}

#water .search-box {
  overflow:auto;}

#water .search-box form {
  margin:0 0;
  padding:5px;
  float:right;}

#water .search-box input {
  padding:5px 3px;
  margin:0 0 1px 0;
  border:1px solid @color-omega;
  color:@color-omega;
  width:115px;
  background:@color-alpha;
  font-size:0.75em}

#water .search-box input.submit {
  border:none;
  padding:3px 0;
  margin:0 0 0 0;
  width:25px;
  height:25px;
  background:url(../images/css/btn.png) no-repeat;}

#rss {
  width:140px;
  margin:20px auto;
  display:block;
  padding:0 0 8px 20px;
  background: url("../images/css/rss_logo.png") 0 3px no-repeat;}

#rss a {
  color:@color-omega;
  text-decoration:none;
  font-weight:bold;}

#rss a:hover {
  color:@color-omega;
  text-decoration:underline;}

#tags {
  width:190px; 
  margin:20px 10px;}

#tags .title {
  text-align:center;
  display:block;
  color:@colore; 
  font-weight:bold; 
  font-size:0.8em; 
  margin:0;
  padding:3px 0;
  background-color:@colorb;}

#tags a {
  color:@colord; 
  line-height:180%;}

#tags a:hover {
  text-decoration:underline; 
  color:@colore;} 

#tags .box {
  padding:5px 15px;
  margin:0;
  background:@color-alpha;
  font-size:0.75em;}

.tag1 {
  font-size: 1em}
  
.tag2 {
  font-size: 1.1em}
  
.tag3 {
  font-size: 1.2em}
  
.tag4 {
  font-size: 1.3em}
  
.tag5 {
  font-size: 1.4em}
