{% extends host_template %}

{% load comments i18n fb_versions cyclope_utils markup %}

{% block content %}

{% alias poll as 'current_object' %}

<div class="content-view poll detail poll-detail">

  <div class="meta-content">{% include 'collections/categories_navigation_block.html' %}</div>

  <h1 class="title">{{ poll.name }}</h1>

  <!-- herramientas -->
  {% include 'cyclope/content_tools_block.html' %}

    <div class="poll_results">
      {% for question in poll.question_set.all %}
        <p>{{ question.text }}</p>
        <ul>
          {% for answer in question.answer_set.all %}
          <li> {{answer.text}} ({{answer.get_votes}}) </li>
          {% endfor %}
        </ul>

      {% endfor %}
    </div>
  {% include 'cyclope/related_contents_block.html' %}


  <div class="clear"></div>

<!--COMENTARIOS -->
  {% include 'comments/comments_block.html' %}

</div> <!--termina poll_detail -->

{% endblock content%}
