{% load i18n cyclope_utils %}

{% with author=current_object.get_author_or_user %}
{% with author_url=author.get_absolute_url %}
{% if author %}
<div class="author-container meta-content">
  <h4  class="author">{% if author_url %}<a href='{{ author_url }}'>{% endif %}{% trans "By" %} {{ author }}{% if author_url %}</a>{% endif %}</h4>
</div>
{% endif %}
{% endwith %}
{% endwith %}

