{% load i18n %}
<!DOCTYPE html>
<html>
  <head>
    <meta charset="utf-8">
    <title>{% trans "Error 500 (Internal Server Error)" %}</title>
  </head>
  <body>
    <p>
      <b>{% trans "Error 500" %}</b>
    </p>
    <p>
      {% trans "Internal server error." %}
    </p>
  </body>
</html>
