{% load i18n cyclope_utils crispy_forms_tags %}
    <h1 class="title">{{ form.title }}</h1>
    {% if form.intro %}
    <div class="form_summary">
        <div class="summary">{{ form.intro|smart_style }}</div>
    </div>
    {% endif %}
    <form class="uniForm" action="{{ form.get_absolute_url }}" method="post"
        {% if form_for_form.is_multipart %}enctype="multipart/form-data"{% endif %}>{% csrf_token %}
        {{ form_for_form|crispy }}
        <div class="buttonHolder">
          <input type="submit" value="{{ form.button_text }}">
        </div>
    </form>
