{% extends host_template %}

{% block content %}
<div class="collection_categories_hierarchy">
  <ul class="cyclope_menu {{ align|lower }}">
  {{ categories|unordered_list }}
  </ul>
</div>
{% endblock content%}

