{% extends host_template %}

{% block content %}
<div class="categories_hierarchy">
{% if collection.visible %}<div class="title">{{ collection.name }}</div>{% endif %}
  <ul>
  {% for category in categories %}
  <li>
    <a href="{% url category-teaser_list category.slug %}">{{ category.name }}</a>
  </li>
{% endfor %}
</ul>
</div>
{% endblock content%}
