/* ------------------------------------------------------------------------------
   
   UNI-FORM DEFAULT by DRAGAN BABIC                         (v2) | Wed, 31 Mar 10
   
   ------------------------------------------------------------------------------
   
   Copyright (c) 2010, Dragan Babic
   
   Permission is hereby granted, free of charge, to any person
   obtaining a copy of this software and associated documentation
   files (the "Software"), to deal in the Software without
   restriction, including without limitation the rights to use,
   copy, modify, merge, publish, distribute, sublicense, and/or sell
   copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following
   conditions:
   
   The above copyright notice and this permission notice shall be
   included in all copies or substantial portions of the Software.
   
   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
   OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
   NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
   HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
   WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
   FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
   OTHER DEALINGS IN THE SOFTWARE.
   
   ------------------------------------------------------------------------------ */

.uniForm{}
    
    .uniForm legend{ font-weight: bold; font-size: 100%; margin: 0; padding: 1.5em 0; }
  
    .uniForm .ctrlHolder{ padding: 1em; border-bottom: 1px solid #efefef; }
    .uniForm .ctrlHolder.focused{ background: #eee; }
    
    .uniForm .inlineLabels .noLabel{}
    
    .uniForm .buttonHolder{ background: #efefef; text-align: right; margin: 1.5em 0 0 0; padding: 1.5em;
                            /* CSS3 */
                            border-radius:         4px;
                            -webkit-border-radius: 4px;
                            -moz-border-radius:    4px;
                            -o-border-radius:      4px;
                            -khtml-border-radius:  4px;
                          }
      .uniForm .buttonHolder .primaryAction{ padding: 10px 22px; line-height: 1; background: #254a86; border: 1px solid #163362; font-size: 12px; font-weight: bold; color: #fff;
                                             /* CSS3 */
                                             border-radius:         4px;
                                             -webkit-border-radius: 4px;
                                             -moz-border-radius:    4px;
                                             -o-border-radius:      4px;
                                             -khtml-border-radius:  4px;
                                             box-shadow: 1px 1px 0 #fff;
                                             -webkit-box-shadow: 1px 1px 0 #fff;
                                             -moz-box-shadow: 1px 1px 0 #fff;
                                             text-shadow: -1px -1px 0 rgba(0,0,0,.25);
                                           }
      .uniForm .buttonHolder .primaryAction:active{ position: relative; top: 1px; }
      .uniForm .secondaryAction            { text-align: left; }
      .uniForm button.secondaryAction      { background: transparent; border: none; color: #777; margin: 1.25em 0 0 0; padding: 0; }
      
        .uniForm .inlineLabels label em,
        .uniForm .inlineLabels .label em{ font-style: normal; font-weight: bold; }
        .uniForm label small{ font-size: .75em; color: #777; }
        
      .uniForm .textInput,
      .uniForm textarea    { padding: 4px 2px; border: 1px solid #aaa; background: #fff; }
      .uniForm textarea    { height: 12em; }
      .uniForm select      {}
      .uniForm .fileUpload {}
      
      .uniForm ul{}
        .uniForm li{}
          .uniForm ul li label{ font-size: .85em; }
            
            .uniForm .small {}
            .uniForm .medium{}
            .uniForm .large {} /* Large is default and should match the value you set for .textInput, textarea or select */
            .uniForm .auto  {}
            .uniForm .small,
            .uniForm .medium,
            .uniForm .auto{}
      
      /* Get rid of the 'glow' effect in WebKit, optional */
      .uniForm .ctrlHolder .textInput:focus,
      .uniForm .ctrlHolder textarea:focus{ outline: none; }
      
      .uniForm .formHint                    { font-size: .85em; color: #777; }
      .uniForm .inlineLabels .formHint      { padding-top: .5em; }
      .uniForm .ctrlHolder.focused .formHint{ color: #333; }
      
/* ----------------------------------------------------------------------------- */
/* ############################### Messages #################################### */
/* ----------------------------------------------------------------------------- */

  /* Error message at the top of the form */
  .uniForm #errorMsg{ background: #ffdfdf; border: 1px solid #f3afb5; margin: 0 0 1.5em 0; padding: 0 1.5em;
                      /* CSS3 */
                      border-radius:         4px;
                      -webkit-border-radius: 4px;
                      -moz-border-radius:    4px;
                      -o-border-radius:      4px;
                      -khtml-border-radius:  4px;
                    }
    .uniForm #errorMsg h3{} /* Feel free to use a heading level suitable to your page structure */
    .uniForm #errorMsg ol{ margin: 0 0 1.5em 0; padding: 0; }
      .uniForm #errorMsg ol li{ margin: 0 0 3px 1.5em; padding: 7px; background: #f6bec1; position: relative; font-size: .85em;
                                /* CSS3 */
                                border-radius:         4px;
                                -webkit-border-radius: 4px;
                                -moz-border-radius:    4px;
                                -o-border-radius:      4px;
                                -khtml-border-radius:  4px;
                              }
  
  .uniForm .ctrlHolder.error,
  .uniForm .ctrlHolder.focused.error{ background: #ffdfdf; border: 1px solid #f3afb5;
                                      /* CSS3 */
                                      border-radius:         4px;
                                      -webkit-border-radius: 4px;
                                      -moz-border-radius:    4px;
                                      -o-border-radius:      4px;
                                      -khtml-border-radius:  4px;
                                    }
    .uniForm .ctrlHolder.error input.error,
    .uniForm .ctrlHolder.error select.error,
    .uniForm .ctrlHolder.error textarea.error{ color: #af4c4c; margin: 0 0 6px 0; padding: 4px; }
  
  /* Success messages at the top of the form */
  .uniForm #okMsg{ background: #c8ffbf; border: 1px solid #a2ef95; margin: 0 0 1.5em 0; padding: 1.5em; text-align: center;
                   /* CSS3 */
                   border-radius:         4px;
                   -webkit-border-radius: 4px;
                   -moz-border-radius:    4px;
                   -o-border-radius:      4px;
                   -khtml-border-radius:  4px;
                 }
    .uniForm #okMsg p{ margin: 0; }

/* ----------------------------------------------------------------------------- */
/* ############################### Columns ##################################### */
/* ----------------------------------------------------------------------------- */

    .uniForm .col{}
    .uniForm .col.first{}
    .uniForm .col.last{}
    .uniForm .col{ margin-bottom: 1.5em; }
    /* Use .first and .last classes to control the layout/spacing of your columns */
    .uniForm .col.first{ width: 49%; float: left; clear: none;                   }
    .uniForm .col.last { width: 49%; float: right; clear: none; margin-right: 0; }
