/**
 * theming styles
 *
 */
body {}
body.frontend_admin {margin: 20px 65px;}
#content {margin:10px auto;width:960px;}
#header {
    /* background: url(/media/admin_tools/images/admin-tools.png) 0 0 repeat-x; */
  background-color: #a00a0a;
}
.login #header {
    border-radius:12px;-webkit-border-radius:12px;-moz-border-radius:12px;}
body.login {background-color: #a00a0a}
.login #content {margin:10px auto;width:400px;}
.login #container {border:none;width:400px;background-color: #a00a0a;
border-radius:6px;-webkit-border-radius:6px;-moz-border-radius:6px;}
.login #header #branding h1 {
    margin: 0;
    padding: 0;
    text-indent: -9999px;
    background: transparent url(../images/cyclope-logo-login.png) no-repeat center center;
    height: 166px;
    width: 400px;
}
.login #content-main {margin:0 0 0 30px;width:400px;}
.login .form-row  {margin:0;}
.login .form-row label {display:block;float:none;margin:0;text-align:left;padding:0;color:#fff;}
.login .form-row input {display:block;float:none;margin:0 0 15px;width:300px !important;text-align:left;padding:6px 3px;font-size:1.1em;
 border-radius:4px;-webkit-border-radius:4px;-moz-border-radius:4px;}
.login .submit-row {display:block;float:none;margin:0 auto;padding:0;width:300px !important;}
.login .submit-row input{display:block;float:right;margin:0 40px 0 0 !important;text-align:center;text-transform:uppercase;font-weight:700;padding:4px !important;color:#fff;background:#1a1a1a;border:2px solid #000;
border-radius:6px;-webkit-border-radius:6px;-moz-border-radius:6px;}
#header #branding h1 {
    margin: 0;
    padding: 5px 10px;
    text-indent: -9999px;
    background: transparent url(../images/cyclope-logo.png) no-repeat left center;
    height: 84px;
    width: 960px;
}

div.breadcrumbs {
    display: block;
    /* display: none; */
    padding: 10px 0;
    border: 0;
    background:none;
    border-bottom: 1px solid #ededed;
    width:960px;
    margin:0 auto 10px;
}

div.breadcrumbs a {
    display: inline;
}

/* ########## fonts ############  */

body, .ui-widget {
 font-family: 'Liberation Sans', Arial, sans-serif;
}

/* ===== misc ======

.addlink {
 background: url("../images/icon_addlink.png") no-repeat scroll 0 1px transparent;
}
.changelink {
 background: url("../images/icon_changelink.png") no-repeat scroll 0 0 transparent;
}

/* ========= change list ======== */

.change-list #content, .change-form #content, .rosetta #content{ 
width: 960px;margin:0 auto;
}

.popup #content{
width: auto !important;
}

#changelist {
padding: 10px; width: auto;
}

#changelist #toolbar{ 
padding: 0;
background: none no-repeat 0 0 transparent;
border: none;
}

.change-list .filtered table, .change-list .filtered .paginator, .filtered #toolbar, .filtered div.xfull, .filtered .actions {
 margin-right:190px !important;
}

/* --- change list search ---- */

#changelist #toolbar #changelist-search{ 
-moz-border-radius: 8px 8px 8px 8px;
padding: 8px 12px 8px 8px;
background: none no-repeat 0 0 white;
display: inline-block;
margin-bottom: 15px;
}


#changelist .actions {
 background: url('../images/actions.png') no-repeat 12px 14px #C3D5F0;
 padding: 8px 12px 8px 35px;
 color: #555;
 -moz-border-radius: 8px 8px 8px 8px;
 border: none;
 margin-bottom: 15px;

}

/* ---- change list top links ---- */

#changelist .xfull {
 margin-bottom: 12px;
}

#changelist ul.toplinks{ 
background: none no-repeat 0 0 transparent;
/* border-bottom: 2px solid #C3D5F0 !important; */
border: none !important;
}

#changelist ul.toplinks li{ 
padding:2px 6px;
width: auto;
border: 1px solid #C3D5F0;
}

/* --- change list tables ---- */

.change-list .filtered table{
margin-bottom: 15px;
width:745px !important;
border-left: 1px solid #83a9de;
border-right: none;
}

.change-list table {
margin-bottom: 15px;
width: inherit;
display: inline-block;
border-left: 1px solid #83a9de;
border-right: none;
}

.change-list .filtered table thead {

}

.change-list .filtered table thead th,
.change-list table thead th{
background: none no-repeat 0 0 #83a9de;
color: white;
border-right: 1px solid #83a9de;
font-weight: normal;
}

table th, table td{
border-right: 1px solid #83a9de !important;
border-bottom: 1px solid #83a9de;
padding: 8px 10px 8px 6px;
}

table tbody tr {
border-bottom: 1px solid #83a9de ;
}

.change-list .filtered table thead th a, .change-list table thead th a{
color: #fff;
}

.change-list .filtered table thead th.sorted a,
.change-list table thead th.sorted a{
color: #fff;
padding-right: 0;
margin-right: 10px;
}

/* ---- change list actions toolbar --- */

#changelist .actions select {
border: 1px solid #83a9de;
margin: 0;
padding: 4px;
}

#changelist .actions select option{
padding: 3px;
}

#changelist .actions label {
font-size: 15px;
color: #fff;
font-weight: bold;
}

#changelist .actions .button {
font-size:12px;
padding:2px 4px;
border: 2px solid #83a9de;
}

/* ---- change list filter ---- */

#changelist-filter {
 border-left: 2px solid #C3D5F0;
 border-bottom: 2px solid #C3D5F0;
-moz-border-radius: 0px 0px 0px 16px;
 background-color: white;
width: 180px;
}

#changelist-filter h2{
 background: url('../images/filter.png') no-repeat 1px 3px #C3D5F0;
 padding-left: 33px !important;
}

#changelist-filter h3, #changelist-filter ul {
 margin: 0; padding: 0;
}

#changelist-filter h3 {
 background-color: #83a9de;
 margin: 12px 11px 0px 11px;
 padding: 2px 3px 2px 7px;
 color: white;
 font-size: 11px;
}

#changelist-filter ul {
 margin: 6px 11px;
}

#changelist-filter li{
margin-left: 0; padding-left: 12px;
}

#changelist-filter li.selected {
border: none;
margin-left: 0; padding-left: 12px;
background: url('../images/filter-on.png') no-repeat 0 0 transparent;
}

#changelist-filter ul.categories-filter li {
margin-left: 0; padding-left: 0px;
}

#changelist-filter ul.categories-filter li.selected {
border: none;
margin-left: 0; padding-left: 12px;
background: url('../images/filter-on.png') no-repeat 0 0 transparent;
}


/* --- change list paginator ---- */

#changelist p.paginator {
background: none no-repeat 0 0 #C3D5F0;
padding: 8px 12px;
text-align: center;
border: none;
-moz-border-radius: 8px 8px 8px 8px;
margin-bottom: 15px;
}

/* --- change list forms --- */


select {
background-color:#FFFFFF;
border:1px solid #83a9de;
font:12px/20px 'Liberation Sans', Arial, sans-serif;
 /* height:2em; WTF!?*/
padding:4px;
vertical-align:top;
}

select option{
padding: 3px;
}

.button, input[type="submit"], input[type="button"], .submit-row input {
background: none no-repeat 0 0 white;
border: 2px solid #C3D5F0;
color:black;
-moz-border-radius: 5px 5px 5px 5px;
padding:2px 4px;
margin-left:0;
}

.login .button, .login input[type="submit"], .login input[type="button"], .login .submit-row input {
background: none no-repeat 0 0 #1a1a1a;
border: 2px solid #000;
color:#eee;
-moz-border-radius: 5px 5px 5px 5px;
padding:2px 4px;
margin-left:0;
}

.button:hover, input[type="submit"]:hover, input[type="button"]:hover, .submit-row input:hover {
background: none no-repeat 0 0 #fff;color:#000;
}
.login .button:hover, .login input[type="submit"]:hover, .login input[type="button"]:hover, .login .submit-row input:hover {
background: none no-repeat 0 0 #1a1a1a;
color:#eee;
}


.button, input[type="text"] {
background: none no-repeat 0 0 white;
border: 1px solid #C3D5F0;
}

/* ------- object tool button (top-right)------- */

#content-main ul.object-tools a:link,
#content-main ul.object-tools a:visited{
 background: none no-repeat 0 0 transparent;
 color:#008000;
}



#content-main ul.object-tools{
 font-family: 'Liberation Sans', Arial, Helvetica, sans-serif;
 margin: -53px 0 0 0 !important; padding: 0 !important;
}

#content-main ul.object-tools li {
 background: none no-repeat 0 0 transparent;
 padding: 10px 10px;
 border: 2px solid #008000;
 background: none no-repeat 0 0 #cfeecf;
 -moz-border-radius: 8px 8px 8px 8px;
}

#content-main ul.object-tools li:hover{
  background: none no-repeat 0 0 #008000;
}

#content-main ul.object-tools li a {
 font-size: 14px;
 line-height: 18px
 float: none; display: inline;
 padding: 0px 0; margin: 0;
 height: auto;
}

#content-main ul.object-tools a.addlink{
  float: none; display: inline;
  padding: 0px 0 0 23px; margin: 0;
  background: url('../images/add-small.png') no-repeat 0 0px transparent;
  color: #008000;
}

#content-main ul.object-tools a.historylink{
  float: none; display: inline;
  padding: 1px 0 2px 25px; /* TODO corregir el png! */
  margin: 0;
  background: url('../images/history-small.png') no-repeat 0 0px transparent;
  color: #008000;
}

#content-main ul.object-tools a.historylink:hover,
#content-main ul.object-tools li:hover a.historylink{
  background: url('../images/history-small.png') no-repeat 0 0px #008000;
  color: white;
}

#content-main ul.object-tools a.viewsitelink:hover,
#content-main ul.object-tools li:hover a.viewsitelink{
  background: none no-repeat 0 0px #008000;
  color: white;
}


#content-main ul.object-tools li:hover a, 
#content-main ul.object-tools a.addlink:hover, 
#content-main ul.object-tools a:hover{
  background: url('../images/add-small.png') no-repeat 0 0px #008000;
  color: white;
}
/* ---- change list help ---- */

.help{
padding: 6px 10px;
margin: 0px 0 10px 10px;
width: 66%;
}

.help p{
margin: 0;
font-size: 14px;
}

/* --- change list titles --- */

.change-list #content h1, .change-form #content h1 { 
}

.change-list #content h2, .change-form #content h2 { 
font-size: 14px;
padding: 7px 12px;
-moz-border-radius: 0px 5px 0px 0px;
}

.change-list #content h3, .change-form #content h3 { 
}

.change-list .module, .change-list .filtered { 
display: block;
-moz-border-radius: 12px 12px 12px 12px;
border: 2px solid #c3d5f0;
background: none !important;
background-color: #e8eff9 !important;
}

/* ################## dashboard ################## */

/* ===== default module ===== */

.dashboard-module {
-moz-border-radius: 0px 0px 0px 0px;
border: none;
margin: 0;
padding: 0;
}

.group .dashboard-module {
padding: 0;
margin: 0;
}

.dashboard-module  h2 {
background: url("../images/engranaje.png") no-repeat scroll 8px 7px #800000;
color: white;
padding-left: 35px;
color: white;
-moz-border-radius: 6px 6px 6px 6px;
font-weight: bold;

}

.dashboard-module-content {
border-top: none;
padding-top: 12px;
width:614px;
}

#module_6 .dashboard-module-content, #module_7 .dashboard-module-content, #module_8 .dashboard-module-content {width:300px;text-align:left !important;padding:0;}
#module_6 .dashboard-module ul.inline, #module_7 .dashboard-module ul.inline, #module_8 .dashboard-module ul.inline {text-align:left !important;}
.dashboard-module ul.inline {text-align:left !important;}
.dashboard-module-content > ul > li { 
display: block;
height: 67px; 
margin: 0 0 13px 0;
-moz-border-radius: 6px 6px 6px 6px;
border: 2px solid #ddd; /* celeste borde c3d5f0; */
background-color: #efefef; /* celeste #e8eff9; */
}

.dashboard-module-content > ul > li:hover { 
background-color: #fff;
}

.dashboard-module-content > ul > li > a {
display: block;
padding-left: 58px;
margin: 11px 0 0 11px;
font-size: 18px;
font-weight: bold;
color: #2b5ea9;
height: 58px;
}

.dashboard-module-content > ul > li > ul {
float: none;
margin: -37px 0 0 64px;
}

.dashboard-module-content > ul > li > ul > li > a{
color: #2B5EA9;
}

/* =========== main area dashboard ========= */

.dashboard-container { 
width: 960px; padding: 0px;margin:0 auto;
}

.main-area-modules { 
width: 645px;
float: left;
margin-top: 0;
}

.main-area-modules  h2 {
background: url("../images/engranaje.png") no-repeat scroll 8px 7px #6e6e6e; /* #2b5ea9; (azul-celeste)*/
padding-left: 35px;
width: 584px;
font-weight: bold;
font-size:1.6em;
 -webkit-border-radius:6px; 
  -moz-border-radius:6px; 
  border-radius:6px; 
}

.main-area-modules.local_app  h2 { /* for local/custom admin panels defined locally */
background: url("../images/estrella.png") no-repeat scroll 8px 7px #698ec6; 
}

.main-area-modules .dashboard-module-content p {
color: #ffcc00;
font-style: italic;
text-align: right;
margin: -38px 38px 21px 0px;
}

.main-area-modules .dashboard-module-content > ul > li { 
display: inline-block;
width: 270px;
margin: 0 17px 13px 0;
border:1px solid #ccc;
 /* Safari 4+, Chrome 1-9 */
   background-image: -webkit-gradient(linear, 0% 0%, 0% 100%, from(#eeeeee), to(#fdfdfd));
   /* Safari 5.1+, Mobile Safari, Chrome 10+ */
   background-image: -webkit-linear-gradient(top, #eeeeee, #fdfdfd); 
   /* Firefox 3.6+ */
   background-image: -moz-linear-gradient(top, #eeeeee, #fdfdfd);
   /* IE 10+ */
   background-image: -ms-linear-gradient(top, #eeeeee, #fdfdfd);
   /* Opera 11.10+ */
   background-image: -o-linear-gradient(top, #eeeeee, #fdfdfd);
     -webkit-border-radius:8px; 
  -moz-border-radius:8px; 
  border-radius:8px; 
}
.main-area-modules .dashboard-module-content > ul > li:hover {background:#fff; }

/* ========== right-area ========= */

.right-area-modules { 
width: 300px;
margin-left: 650px;
-moz-border-radius: 0px 0px 0px 0px;
margin-top: 20px;
/* display: none; */
}

.right-area-modules .float-right {
float: none;
display: block;
margin-right: 6px;

}

.right-area-modules .dashboard-module-content {
padding-top: 0;
}
.right-area-modules .dashboard-module-content > ul > li {
-moz-border-radius: 0px 0px 0px 0px;
background: none no-repeat 0 0 transparent;
border: none;
border-top: 1px solid #efdede;
height: auto;
display: block;
width: auto;
margin: 0;
}

.right-area-modules .dashboard-module-content > ul > li.odd {
background: none no-repeat 0 0 transparent;
-moz-border-radius: 0px 0px 0px 0px;
} 

.right-area-modules .dashboard-module-content > ul > li > a {
display: block;
padding: 0 15px;
margin: 0;
font-size: 14px;
font-weight: normal;
color: #666;
height: auto;
}

.right-area-modules {
border: 2px solid #a00a0a;
 -webkit-border-radius:6px; 
  -moz-border-radius:6px; 
  border-radius:6px; 
}

.right-area-modules h2 {
background: url("../images/right-area-default-icon.png") no-repeat scroll 8px 7px #a00a0a;
-moz-border-radius: 3px 3px 0px 0px;
}

/* --- feeds --- */

.dbmodule-recent-actions h2 {
background: url('../images/feed-small.png') no-repeat 8px 7px #800000;
}

.dbmodule-feed ul li a.external-link {
background: url('../images/codigo_sur-ext-link.png') no-repeat 0 5px transparent;
}

/* --- history --- */

.dbmodule-recent-actions h2 {
background: url('../images/history-small.png') no-repeat 8px 7px #800000;
}


/* ====== iconos ======== */

.dashboard-module-content > ul > li > a[href="/admin/articles/article/"] {
background: url("../images/admin-articles-article.png") no-repeat scroll 0 1px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/staticpages/staticpage/"] {
background: url("../images/admin-staticpages-staticpage.png") no-repeat scroll 0 1px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/staticpages/htmlblock/"] {
background: url("../images/admin-staticpages-blockhtml.png") no-repeat scroll 0 1px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/newsletter/newsletter/"] {
background: url("../images/admin-newsletter-newsletter.png") no-repeat scroll 0 1px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/cyclope/layout/"] {
background: url("../images/admin-cyclope-layout.png") no-repeat scroll 0 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/feeds/feed/"] {
background: url("../images/admin-feeds-feed.png") no-repeat scroll 0 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/polls/poll/"] {
background: url("../images/admin-polls-poll.png") no-repeat scroll 0 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/polls/question/"] {
background: url("../images/admin-polls-question.png") no-repeat scroll 0 2px transparent;
}
.dashboard-module-content > ul > li > a[href="/admin/contacts/contact/"] {
background: url("../images/admin-contacts-contact.png") no-repeat scroll 0 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/cyclope/menuitem/"] {
background: url("../images/admin-cyclope-menuitem.png") no-repeat scroll 0 2px transparent;
}

.dbmodule-content_sites a {
background: url("../images/admin-sites-site.png") no-repeat scroll 0 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/cyclope/menu/"] {
background: url("../images/admin-cyclope-menu.png") no-repeat scroll 0 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/registration/registrationprofile/"] {
background: url("../images/admin-registration-registrationprofile.png") no-repeat scroll 0 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/medialibrary/soundtrack/"] {
background: url("../images/admin-medialibrary-soundtrack.png") no-repeat scroll 0 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/medialibrary/flashmovie/"] {
background: url("../images/admin-medialibrary-flashmovie.png") no-repeat scroll 0 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/medialibrary/movieclip/"] {
background: url("../images/admin-medialibrary-movieclip.png") no-repeat scroll 0 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/medialibrary/picture/"] {
background: url("../images/admin-medialibrary-picture.png") no-repeat scroll 0 2px transparent;
}


.dashboard-module-content > ul > li > a[href="/admin/medialibrary/regularfile/"] {
background: url("../images/admin-medialibrary-regularfile.png") no-repeat scroll 0 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/medialibrary/document/"] {
background: url("../images/admin-medialibrary-document.png") no-repeat scroll 0 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/medialibrary/externalcontent/"] {
background: url("../images/admin-medialibrary-externalcontent.png") no-repeat scroll 0 2px transparent;
}


.dashboard-module-content > ul > li > a[href="/admin/cyclope/author/"] {
background: url("../images/admin-cyclope-author.png") no-repeat scroll 0 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/cyclope/source/"] {
background: url("../images/admin-cyclope-source.png") no-repeat scroll 0 2px transparent;
}


.dashboard-module-content > ul > li > a[href="/admin/auth/user/"] {
background: url("../images/admin-auth-user.png") no-repeat scroll 0 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/auth/group/"] {
background: url("../images/admin-auth-group.png") no-repeat scroll 0 0px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/cyclope/image/"] {
background: url("../images/admin-cyclope-image.png") no-repeat scroll 0 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/comments/comment/"] {
background: url("../images/admin-comments-comment.png") no-repeat scroll 0 3px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/collections/collection/"] {
background: url("../images/admin-collections-collection.png") no-repeat scroll 0 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/collections/category/"] {
background: url("../images/admin-collections-category.png") no-repeat scroll -2px 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/cyclope/sitesettings/1/"] {
background: url("../images/admin-cyclope-sitesettings.png") no-repeat scroll 0 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/tagging/taggeditem/"] {
background: url("../images/admin-tagging-taggeditem.png") no-repeat scroll 0 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/tagging/tag/"] {
background: url("../images/admin-tagging-tag.png") no-repeat scroll 0 2px transparent;
}

.dashboard-module-content > ul > li > a[href="/admin/contact_form/contactformsettings/1/"] {
background: url("../images/admin-contact_form-contactformsettings.png") no-repeat scroll 0 2px transparent;
}

/* ####### !! ####### */
/*html[lang="es-ar"]*/
 .dashboard-module-content > ul > li > a[href="/admin/contact_form/contactformsettings/"] {
background: url("../images/admin-contact_form-contactformsettings.png") no-repeat scroll 0 2px transparent;
/* texto demasiado largo de contact:_form !! */
margin:9px 0 11px 11px;
font-size: 14px;
line-height: 16px;
}
/* ####### !! ####### */

.dashboard-column {float:none !important;margin:0 auto !important;}
h1.dashboard-title {float:none !important;width:960px;margin:30px auto 0;float:none;color:#ccc;display:none;}
#header {position:relative;}
#branding {width:960px;margin:0 auto;}
#user-tools {width:960px;position:relative;margin:-40px auto 0;}
.group ul {background:transparent;}
#footer {width:960px;margin:10px auto;border-top:1px dotted #ccc;text-align:center;}
.login #footer {display:none;}
ul.messagelist li {width:880px !important;margin:0 auto !important;padding:20px 40px;background-position:20px center;font-size:1.2em;}
.changelink {background: url("../images/admin-cyclope-sitesettings-small.png") no-repeat !important;}