{% extends 'medialibrary/medialibrary_slideshow_base_item.html' %}
{% load i18n fb_versions cyclope_utils dbgettext_tags %}

{% block content %}
    {% with player_height='24' %}
    {% include 'medialibrary/media_player.html' %}
    {% endwith %}
{% endblock content %}
