{% extends 'collections/category_contents_base.html' %}

{% load i18n cyclope_utils %}

{% block category_content %}

  {% comment %}
  We show a teaser view of every object belonging to this category.
  {% endcomment %}

  <div class="icon_list_container">

  {% for categorization in categorizations %}
    {% join categorization.content_type.app_label  "/" categorization.content_type.model "_" inline_view_name ".html" as template_path %}

    {% comment %}
      we alias the actual object with the model name
      so the included template is reusable
      and can access the content object using an explicit name
    {% endcomment %}

    {% alias categorization.content_object as categorization.content_type.model %}
    {% include template_path with current_object=categorization.content_object %}
  {% endfor %}

  </div>
  <br class="clear" />

{% endblock %}
