{% extends host_template %}

{% block content %}
  <ul>
  {% for menu_item in menu_items %}
    <li class="{% if current_url == menu_item.url or request.path_info|slice:'1:' == menu_item.url %}current{% endif%}{% if menu_item.site_home %} site_home{% endif %}">
      {% if menu_item.custom_url %}
        <a href="{{menu_item.url}}">
      {% else %}
        <a href="/{{CYCLOPE_PREFIX}}{{menu_item.url}}">
      {% endif %}
        <span>{{ menu_item.name }}</span>
      </a>
    </li>
  {% endfor %}
  </ul>
{% endblock content%}
