{% extends host_template %}

{% load i18n fb_versions cyclope_utils dbgettext_tags %}

{% block content %}
<div class="content-view author detail author-detail">
  <h1 class="title">{{ current_object.name }}</h1>

  {% if current_object.origin %}
  <div class="origin">{{ current_object.origin }}</div>
  {% endif %}

  {% if current_object.notes %}
  <div class="notes">{{ current_object.notes|smart_style }}</div>
  {% endif %}

  {% if current_object.image %}
  <div class="media-content">
    <img src="{% version media.image.path 'croppedthumbnail' %}" />
  </div>
  {% endif %}

  {% include "cyclope/authored_content_block.html" %}
</div>
{% endblock content%}
