{% extends CYCLOPE_DEFAULT_TEMPLATE %}
{% load i18n crispy_forms_tags %}

{% block content %}

<h1 class="title">{% trans "Change password" %}</h1>

<form enctype="multipart/form-data" method="post" class="uniForm change_password">{% csrf_token %}
  {{form|crispy}}
  <div class="buttonHolder">
    <input type="submit" name="post" class="submit" value="{% trans "Change" %}" />
  </div>
</form>

{% endblock %}
