/*
# Cyclope 3 GPL
# Neutronix Workflow Design
# Layouts: 4 & 5 Elements
# Copyright 2010-2012 CodigoSur - SociedadCivil
# All rights reserved.
# This file is part of Cyclope 3.
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# Development: Codigo Sur www.codigosur.org
# Less CSS based www.lesscss.org
# 960 Grid System Based www.960.gs
# Neutronix is developed by Santiago Hoerth Moura
*/


/*-----------------------------------------------------------------------------------------------
LOVE
-----------------------------------------------------------------------------------------------*/
#love {
  position:relative;
  background:@colora;
  padding:10px;
  margin-top:0px;
  .rounded-corners(6px);}

#love .content-view {
  }

#love .more {
  font-size:inherit;
  font-weight:400;
  margin:0; 
  padding: 0 0;
  display:inline;}

#love .pagination  {
  font-size:0.65em;
  text-align:center;
  padding:3px;
  background:@colore;
  color:@colora;}

#love .pagination a {
  color:@color-alpha;
  text-decoration:underline;}

#love .author {
  font-size:0.8em;
  font-weight:700;
  margin:10px 0 0;
  color:@colord;
  padding:0 0 0 10px;}

#love .teaser {
  margin:0 0 10px;
  padding:0 0 5px 0;
  overflow:auto;
  border-bottom:1px dotted @colorc;}

#love .teaser .title {
  margin:0 0 10px 0;
  color:@color-omega;
  position:relative;
  overflow:auto;
  font-size:.95em;
  padding:7px 0 0;
  border-bottom:none;
  .rounded-corners(6px);}

#love .teaser .title a {
  text-decoration:none;
  color:inherit;}

#love .teaser .title a:hover {
  text-decoration:underline;
  color:@color-omega;}  

#love .teaser .author {
  font-size:0.8em;
  font-weight:700;
  margin:10px 0 0;
  color:@colord;padding:0;}

#love .teaser .tile img {
  }

#love .teaser img.teaser_icon {
  float:left;
  width:60px;
  padding:0;
  border:1px solid @color-omega;
  background:@color-alpha;
  margin:3px 5px 0 0;}

#love .teaser .pretitle, #love .teaser .date {
  margin:0 0 5px;
  font-size:0.6em;
  display:inline;
  text-align:right;
  text-transform:none;
  color:@color-omega;padding:0 0 5px 5px;
  .rounded-corners(4px);}

#love .teaser .date {
  padding:0;}
 
#love .teaser img.icon {
  float:right;
  width:150px;
  clear:both;
  padding:3px;
  border:3px solid @colorb;
  margin:0 0 20px 20px;}

#love .teaser img.type_icon {
  width:20px;
  padding:0;
  margin:0 0;
  float:right;}

#love .teaser .summary {
  color:@colore;
  font-weight:400;
  padding:0;
  text-align:left;
  line-height:1.2em;
  font-size:.8em;
  margin:-3px 0 5px;}

#love .teaser .summary p {
  display:inline;}

#love .teaser ul {
  color:@color-omega;
  font-size:1em;
  padding:15px 0;
  margin:0 0 0 30px;
  list-style:square;}

#love .teaser li {
  margin:0 0 0 5px;
  padding:0 0 3px;}

#love .category_title .title {
  padding:10px 0;
  margin:0 0 10px;
  display:block;
  border-bottom:none;
  font-size:1em;
  text-align:center;
  background:@colore;
  color:@color-alpha;
  .rounded-corners(6px);}

#love .category_title .title a {
  color:@color-alpha;}

#love .staticpage-teaser {
  border-bottom:3px solid @colorb;
  padding:0 0 10px;
  margin:0 0 10px;}

#love .staticpage-teaser ul li h2 {
  font-size:.9em;
  margin:0 0 10px;}

#love .staticpage-teaser ul  {
  list-style:square;
  margin:0 15px;}

#love .staticpage-detail {
  border-bottom:3px solid @colorb;
  padding:0 0 10px;
  margin:0 0 10px;
  font-size:.8em;}

#love .categories_hierarchy .title {
  font-weight:700;
  padding:10px 0;
  margin:0 0 5px;
  display:block;
  border-bottom:none;
  font-size:1em;
  text-align:center;
  background:@colore;
  color:@color-alpha;
  .rounded-corners(6px);}

#love .categories_hierarchy .title a {
  color:@color-alpha;}

#love .menuitems_hierarchy,
#love .categories_hierarchy,
#love .categories_hierarchy_to_iconlist,
#love .flat_items_list,
#love .root_items_list,
#love .menuitem,
#love .menuitems_hierarchy {
  margin:0 0 10px;
  padding:0 0 10px;
  border-bottom:3px solid @colorb;}

#love .menuitems_hierarchy span,
#love .categories_hierarchy span,
#love .categories_hierarchy_to_iconlist span,
#love .flat_items_list span,
#love .root_items_list span  {
  }

#love .menuitems_hierarchy ul,
#love .categories_hierarchy ul,
#love .categories_hierarchy_to_iconlist ul,
#love .flat_items_list ul,
#love .root_items_list ul,
#love .menuitem ul,
#love .category_root_item_list ul {
  margin:0 ;
  padding:0;
  list-style:none;display:block;}


#love .menuitems_hierarchy li ,
#love .categories_hierarchy li,
#love .categories_hierarchy_to_iconlist li,
#love .flat_items_list li
#love .root_items_list li,
#love .menuitem li,
#love .category_root_item_list li {
  font-size:.8em;
  margin:4px 0;
  text-decoration:none;
  font-weight:700;
  border:1px solid @colorb;
  background-color:@colora;
  padding:8px 10px;
  .rounded-corners(6px);}

#love .menuitems_hierarchy li a ,
#love .categories_hierarchy li a,
#love .categories_hierarchy_to_iconlist li a,
#love .flat_items_list li a,
#love .root_items_list li a,
#love .menuitem li a,
#love .category_root_item_list li a {
  text-decoration:none;
  color:@color-omega;
  display:block;}

#love .menuitems_hierarchy li a:hover,
#love .categories_hierarchy li a:hover,
#love .categories_hierarchy_to_iconlist li a:hover,
#love .flat_items_list li a:hover,
#love .root_items_list li a:hover,
#love .menuitem li a:hover,
#love .category_root_item_list a:hover {
  text-decoration:underline;
  color:@colore;}

#love .menuitems_hierarchy ul ul,
#love .categories_hierarchy ul ul,
#love .categories_hierarchy_to_iconlist ul ul,
#love .flat_items_list ul ul,
#love .root_items_list ul ul,
#love .menuitem ul ul,
#love .category_root_item_list ul ul {
  margin:0;
  padding:0;
  display:block;
  border:none;}

#love .menuitems_hierarchy li li,
#love .categories_hierarchy li li,
#love .categories_hierarchy_to_iconlist li li,
#love .flat_items_list li li,
#love .root_items_list li li,
#love .menuitem li li,
#love .category_root_item_list li li {
  display:block;
  padding:3px 0;
  margin:4px 0;
  border:none;
  border-bottom:1px solid @colorb;}

#love .menuitems_hierarchy li li a,
#love .categories_hierarchy li li a,
#love .categories_hierarchy_to_iconlist li li a,
#love .flat_items_list li li a,
#love .root_items_list li li a,
#love .menuitem li li a,
#love .category_root_item_list li li a {
  display:block;
  background:@color-alpha;
  color:@color-omega;
  text-decoration:none;}

#love .menuitems_hierarchy li li a:hover,
#love .categories_hierarchy li li a:hover,
#love .categories_hierarchy_to_iconlist li li a:hover,
#love .flat_items_list li li a:hover,
#love .root_items_list li li a:hover,
#love .menuitem li li a:hover,
#love .category_root_item_list li li a:hover {
  display:block;
  background:@color-alpha;
  color:@color-omega;
  text-decoration:none; }

#love .menuitems_hierarchy ul ul ul,
#love .categories_hierarchy ul ul ul,
#love .categories_hierarchy_to_iconlist ul ul ul,
#love .flat_items_list ul ul ul,
#love .root_items_list ul ul ul,
#love .menuitem ul ul ul,
#love .category_root_item_list ul ul ul {
  position:relative;
  left:170px;
  top:-21px;
  background:@colora;}

#love .menuitems_hierarchy li li li,
#love .categories_hierarchy li li li,
#love .categories_hierarchy_to_iconlist li li li,
#love .flat_items_list li li li,
#love .root_items_list li li li,
#love .menuitem li li li,
#love .category_root_item_list li li li {
  background:@colord;}

#love .menuitems_hierarchy li li li a,
#love .categories_hierarchy li li li a,
#love .categories_hierarchy_to_iconlist li li li a,
#love .flat_items_list li li li a,
#love .root_items_list li li li a,
#love .menuitem li li li a,
#love .category_root_item_list li li li a {
  color:@color-alpha;}

#love .menuitems_hierarchy p,
#love .categories_hierarchy p,
#love .categories_hierarchy_to_iconlist p,
#love .flat_items_list p,
#love .root_items_list p,
#love .menuitem p,
#love .menuitems_hierarchy p {
  clear:left;}	

#love .menuitems_hierarchy #current,
#love .categories_hierarchy #current,
#love .categories_hierarchy_to_iconlist #current,
#love .flat_items_list #current,
#love .root_items_list #current,
#love .menuitem #current,
#love .menuitems_hierarchy #current {
  background:url(images/current-bg.gif) top left repeat-x;
  color:@color-alpha;}


#love .collection_header .title {
  padding:10px 0;
  margin:0 0 5px;
  display:block;
  border-bottom:none;
  font-size:1em;
  text-align:center;
  background:@colore;
  color:@color-alpha;
  .rounded-corners(6px);}

#love .collection_teaser {
  margin:0 0 10px;
  border-bottom:1px solid @color-omega;
  padding:0 0 10px;}

#love .collection_teaser .summary {
  color:@colore;
  font-weight:700;
  padding:0;
  text-align:left;
  line-height:1.5em;
  font-size:.8em;}

#love .collection_teaser .summary p {
  display:block;}

#love .collection_teaser img.image {
  float:none;
  width:170px;
  margin:0;
  padding:0;}

#love .labeled_icon .title {
  font-size:.55em;
  text-align:center;
  padding:1px;
  border:none;
  font-weight:400;}

#love .labeled_icon img.icon {
  height:60px;
  width:60px;}

#love div.labeled_icon {
  width:60px;
  height:110px;
  border:2px solid @colorc;
  background:@colora;
  display:block;
  margin:0 5px 5px ;
  float:left;
  padding:5px 5px ;
  position:relative;
  .rounded-corners(8px);}

#love div.labeled_icon img.type_icon {
  width:12px;
  position:absolute;
  top:10px;
  left:10px;}

#love .labeled_icon_list {
  display:block;
  float:none;
  overflow:auto;
  margin:0 0 10px;
  padding:0 0 5px;
  border-bottom:3px solid @colorb;}

#love .icon_list_container {
  margin:0 0 5px;
  overflow:auto;}

#love div.paginator {
  font-size:.7em;
  padding:5px;
  background:@colorc;
  color:@color-alpha;
  display:block;
  font-weight:700;
  text-align:center;
  margin:0 auto 10px;
  .rounded-corners(4px);}

#love div.paginator a {
  color:@color-alpha;
  font-weight:400;
  text-decoration:underline;}

#love div.paginator a:hover {
  color:@color-omega;}

#love .teaser_list, #love .collection_all_items_teaser_list {
  margin:0;
  padding:0;}

#love .contact-teaser {
  border-bottom:1px solid @colorc;
  padding:5px 0;
  margin:0;}

#love .contact-teaser img.type_icon {
  display:none;}

#love .contact-teaser .title {
  display:inline;
  margin:0 0 10px 0;
  color:@color-omega;
  font-weight:700;
  font-size:.9em;
  padding:0;
  background:none;
  border:none;}

#love .contact-teaser .title a {
  text-decoration:none;
  color:@color-omega;
  display:inline;}

#love .contact-teaser .title a:hover {
  text-decoration:underline;
  color:@colorc;}

#love .contact-teaser .title img.photo {
  width:30px;
  float:left;
  padding:0 5px 0 0;}

#love .contact-teaser .contact-details {
  display:none;}

#love form .title {
  color:@color-omega;
  font-weight:700;}

#love form small {
  font-size:0.7em;
  padding:5px 0;
  display:block;}

#love form input {
  padding:2px;
  width:130px;
  .rounded-corners(3px);
  background:@color-alpha;
  color:@color-omega;
  border:1px solid @color-omega;}

#love form input.submit {
  width:30px;
  background:@colord;
  color:@color-alpha;
  border:1px solid @color-omega;}

#love .tags {
  margin:0;
  padding:10px 0 0;
  font-size:0.7em;
  display:block;}
 
#love .tags a {
  color: @colord}

#love .tags a:hover {
  color:@color-omega; 
  text-decoration:underline;}

#love .search-box {
  overflow:auto;}

#love .search-box form {
  margin:0 0;
  padding:5px;
  float:right;}

#love .search-box input {
  padding:5px 3px;
  margin:0 0 1px 0;
  border:1px solid @color-omega;
  color:@color-omega;
  width:115px;
  background:@color-alpha;
  font-size:0.75em}

#love .search-box input.submit {
  border:none;
  padding:3px 0;
  margin:0 0 0 0;
  width:25px;
  height:25px;
  background:url(../images/css/btn.png) no-repeat;}
