{% load i18n cyclope_utils %}

   {% if page.paginator.num_pages != 1 %}
    <div class="paginator">
        <span class="step-links">
            {% if page.has_previous %}
                {# query is present when this block is included in the search view #}
                <a href="?{% append_to_get page=1 %}">{% trans 'first' %}</a>&nbsp
                <a href="?{% append_to_get page=page.previous_page_number %}">{% trans 'previous' %}</a>
            {% endif %}

            <span class="current">
               {% trans 'Page' %} {{ page.number }} {% trans 'of' %} {{ page.paginator.num_pages }}
            </span>

            {% if page.has_next %}
                <a href="?{% append_to_get page=page.next_page_number %}">{% trans 'next' %}</a>&nbsp
                <a href="?{% append_to_get page=page.paginator.num_pages %}">{% trans 'last' %}</a>
            {% endif %}
        </span>
    </div>
   {% endif %}

