{% load comments i18n fb_versions cyclope_utils dbgettext_tags %}

{% block content %}
<div class="content-view article inline_detail article-inline_detail">
  {% if article.pretitle %}
  <span class="pretitle">{% trans article.pretitle %}</span>
  {% endif %}

  {% if show_ToC %}
    <span class="ToC_link"><a href="#ToC">{% trans "Return to Table of Contents" %}</a></span>
  {% endif %}

  <a name="article__{{ article.slug }}" href="{% url article-detail article.slug %}">
    <h3 class="title">{% trans article.name  %}</h3>
  </a>

  {% if article.summary %}
  <div class="summary">{{ article|parsed_gettext:"summary"|smart_style }}</div>
  {% endif%}

  {% include "cyclope/author_block.html" %}

  <div class="article_content">
    {% if article.pictures %}
      <img src="{% version article.pictures.0.image.path 'small' %}" alt="{{ article.pictures.0.name }}" hspace="0" vspace="0" align="right" />
    {% endif %}

    <div class="html-text html-content text">
      {{ article|parsed_gettext:"text"|smart_style}}
    </div>
  </div>
</div> <!--termina article_detail -->
{% endblock content%}
