<!DOCTYPE html>
<!--
# Cyclope 3 GPL
# Neutronix Workflow Design
# Layouts: 4 & 5 Elements
# Copyright 2010-2012 CodigoSur - SociedadCivil
# All rights reserved.
# This file is part of Cyclope 3.
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# Development: Codigo Sur www.codigosur.org
# Less CSS based www.lesscss.org
# 960 Grid System Based www.960.gs
# Neutronix is developed by Santiago Hoerth Moura
 -->

{% load layout i18n cyclope_utils compress %}

<html>

<head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
    <title>{% block title %}{{ CYCLOPE_SITE_SETTINGS.global_title }}{%endblock%}</title>
    <meta name="Keywords" content="{{ CYCLOPE_SITE_SETTINGS.keywords }}" />
    <meta name="Description" content="{{ CYCLOPE_SITE_SETTINGS.description }}" />
    <link href="/rss" title="RSS" type="application/rss+xml" rel="alternate" />
    {% compress css %}
    {% block displaycss %}
    {% block neutronixcss %}
    <link href="{{ CYCLOPE_THEME_MEDIA_URL }}css/cyclope.less" rel="stylesheet{% if not COMPRESS_ENABLED %}/less{% endif %}" type="text/less"/>
    {% endblock neutronixcss %}
    <link href="{{ CYCLOPE_STATIC_URL }}themes/neutronix/css/print.css" rel="stylesheet" type="text/css" media="print"/>
    <link href="{{ CYCLOPE_STATIC_URL }}js/lightbox/css/jquery.lightbox-0.5.css" rel="stylesheet" type="text/css" media="screen"/>
    <link rel="stylesheet" href="{{ CYCLOPE_STATIC_URL }}css/uni-form.css" type="text/css" />
    <link rel="stylesheet" href="{{ CYCLOPE_STATIC_URL }}css/default.uni-form.css" type="text/css" />
    {% endblock displaycss %}
    {% endcompress %}
    {% if not COMPRESS_ENABLED %}
    <script type="text/javascript" src="{{ CYCLOPE_STATIC_URL }}js/less.min.js"></script>
    {% endif %}
    <script type="text/javascript" src="{{ CYCLOPE_STATIC_URL }}js/jquery.min.js"></script>
    <script type="text/javascript" src="{{ CYCLOPE_STATIC_URL }}js/menuitems.js"></script>
    <script type="text/javascript" src="{{ CYCLOPE_STATIC_URL }}js/lightbox/js/jquery.lightbox-0.5.pack.js"></script>
    <script type="text/javascript" src="{{ CYCLOPE_STATIC_URL }}js/uni-form.jquery.min.js" ></script>
    {% if CYCLOPE_SITE_SETTINGS.enable_ratings %}
    <script type="text/javascript" src="{{ CYCLOPE_STATIC_URL }}js/ratings.js" ></script>
    {% endif %}
    <script type="text/javascript">
    $(function() {
        $('#gallery a').lightBox({
            overlayBgColor:         '#000',
            overlayOpacity:         0.8,
            fixedNavigation:        false,
            imageLoading:           '{{ CYCLOPE_STATIC_URL }}js/lightbox/images/lightbox-ico-loading.gif',
            imageBtnPrev:           '{{ CYCLOPE_STATIC_URL }}js/lightbox/images/lightbox-btn-prev.gif',
            imageBtnNext:           '{{ CYCLOPE_STATIC_URL }}js/lightbox/images/lightbox-btn-next.gif',
            imageBtnClose:          '{{ CYCLOPE_STATIC_URL }}js/lightbox/images/lightbox-btn-close.gif',
            imageBlank:             '{{ CYCLOPE_STATIC_URL }}js/lightbox/images/lightbox-blank.gif',
            containerBorderSize:    10,
            containerResizeSpeed:   400,
            txtImage:               '{% trans "Image"%}',
            txtOf:                  '{% trans "of"%}'
        });
    });
    </script>
    <script type="text/javascript">
     $(function(){
       $('form.uniForm').uniform();
     });
    </script>
    {% block extra_head %}{% endblock %}
</head>

<body class="{% block body_class %}{%endblock%}">

{% block page_header %}
<div id="mask" class="container_24">
{% region 'air' %}
  <div class="brand">
    <h1><a href="/">{{ CYCLOPE_SITE_SETTINGS.global_title }}</a></h1>
    <h2><a href="/">http://{{ CYCLOPE_SITE_SETTINGS.site.domain }}</a></h2>
  </div>
  <div class="clear"></div>
{% endblock %}

  <div id="middling">{% block page_content %} {% endblock %}</div>

{% block page_footer %}
  {% include "cyclope/themes/neutronix/footer.html" %}
</div><!-- /end mask -->
{% endblock %}
</body>
</html>
