{% extends host_template %}


{% load i18n %}

{% block content %}

  {% include 'cyclope/alphabetical_pagination_block.html' %}

  {% for contact in contacts %}

    {% include "contacts/contact_teaser.html" %}
  {% endfor %}

{% endblock %}
