{% load fb_versions cyclope_utils %}

<div class="content-view media labeled_icon {{ current_object.get_object_name }}">

  <a href="{% if current_object.skip_detail %}{{ current_object.content_url }}{% else %} {{ current_object.get_absolute_url }} {% endif%}" {% if current_object.new_window %}target="_blank"{% endif%}>
    {% if current_object.image %}
      <img class="type_icon" src="{{ CYCLOPE_THEME_MEDIA_URL }}images/icons/{{ current_object.get_object_name }}.png" border="0"/>
      <img class="icon" src="{% version current_object.image.path 'thumbnail' %}" border="0"/>
    {% else %}
      <img class="type_icon" src="{{ CYCLOPE_THEME_MEDIA_URL }}images/icons/{{ current_object.get_object_name }}.png" border="0"/>
      <img class="icon" src="{{ CYCLOPE_THEME_MEDIA_URL }}images/icons/not-available.png" border="0"/>
    {% endif %}
  </a>

  <h2 class="title">
    <a href="{% if current_object.skip_detail %}{{ current_object.content_url }}{% else %} {{ current_object.get_absolute_url }} {% endif%}" {% if current_object.new_window %}target="_blank"{% endif%}>
    {{ current_object.name|truncatechars:40 }}
    </a>
  </h2>
</div>
