{% extends CYCLOPE_DEFAULT_TEMPLATE %}
{% load i18n %}


{% block content %}

<h3>{% trans "Your account is now active" %}</h3>
<p>{% trans "You may now" %} <a href="/accounts/login?next={{next}}">{% trans "login" %}</a></p>

{% endblock %}
