{% extends host_template %}
{% load i18n %}

{% block extra_head %}
{% endblock %}

{% block content %}
<div class="content-view comment comments-list">
  {% include 'comments/list.html' %}
</div>
{% endblock %}

