from django.utils.translation import ugettext_lazy as _

# django

_("Username")

# haystack

_("Search In")

# others

_("Lookup")

_("Share in your social networks")

_("Shortcuts")

_("Collapse tree")

_("Expand tree")

_("and")

_("or make changes")

_("Post")

_("Neutronica theme")

_("One sidebar")

_("left sidebar")

_("footer")

_("Two sidebars")

_("right sidebar")

_("No sidebars")

_("Subscribe to RSS")

_("User")

_("A user with that username already exists.")

_("username")

_("users")

_("sender")

_("Visit website")

_("Categories")

_("Name")

_("Alignment")

_("Text")

_("Date")

_("Share")

_("Review and moderate user comments")

_("alphabetical teaser list of Contact members")

_("Categorization")

_("Classify the content in your website")

_("Modify the menus and site layouts")

_("Header")

_("show the current content for the selected Newsletter")

_("show the header text of the selected Newsletter")

_("toggle editor")

_("on")

_("off")

_("collection categories")

_("Spanish")

_("English")

_("Portuguese")

_("list of Products")

_("price")

_("product")

_("products")

_("Potente theme")

_("One sidebar and four panes")

_("sidebar")

_("second pane")

_("third pane")

_("fourth pane")

_("Translated")

_("article image")

_("article images")

_("attachments")

_("downloads")

_("Codigo Sur, latest news")

_("navigation breadcrumb")

_("Categories for this")

_("category map")

_("%(more_count)s more")
