{% load i18n fb_versions %}

  <div class="content-view contact teaser contact-teaser">

 {% if contact.photo %}
	<div class="title">
  
    <img class="photo" src="{% version contact.photo 'cropped' %}" />
    <img class="type_icon" src="{{ CYCLOPE_THEME_MEDIA_URL }}images/icons/contact.png" alt="contact" />
    <a  href="{% url contact-detail contact.slug %}">{{ contact }}</a>
     </div>
	 {% else %}
  		<div class="title">
    <img class="photo" src="/media/uploads/images/contacts/no-photo.png" alt="no photo" />
    <img class="type_icon" src="{{ CYCLOPE_THEME_MEDIA_URL }}images/icons/contact.png" alt="contact" />
    <a  href="{% url contact-detail contact.slug %}">{{ contact }}</a>
     </div>
    	 {% endif %}  
    <div class="contact-details">
      <ul>
        <li>{% trans "Gender" %}: {{contact.gender}}</li>
        <li>{% trans "Email" %}: {{contact.email}}</li>
        <li>{% trans "Web" %}: {{contact.web}}</li>
        <li>{% trans "Mobile" %}: {{contact.mobile_phone_number}}</li>
      </ul>

      <span class="more"><a href="{% url contact-detail contact.slug %}"> {% trans "More" %}</a></span>
      <span class="last_change">{% trans "Last change" %}: {{ contact.get_last_change_date }}</span>
    </div>

    <div class="clear"></div>

  </div>
