{% extends host_template %}

{% block content %}
<div class="staticpage-teaser">
<ul>
{% for staticpage in staticpage_list %}
  <li><h2>
    <a href="{% url staticpage-detail staticpage.slug %}">
    {{  staticpage.name}}
    </a></h2>
  </li>
{% endfor %}
</ul>
</div>
{% endblock content%}
