{% load i18n fb_versions dbgettext_tags cyclope_utils %}

  <div class="content-view article teaser article-teaser">

    <div class="pretitle-container first meta-content">
      {% if  article.pretitle and not simplified_view %}
      <div class="pretitle">{% trans article.pretitle %}
        {% if article.date %}<span class="pretitle-separator"> | </span>{% endif %}</div>
      {% endif%}

      {% if article.date %}
      <div class="date">{{ article.date|date:'SHORT_DATE_FORMAT' }}</div>
      {% endif %}
    </div>

    <h2 class="title"><img class="type_icon" src="{{ CYCLOPE_THEME_MEDIA_URL }}images/icons/article.png" />
      <a href="{{ article.get_absolute_url }}">{{ article.name }}</a>
    </h2>

    {% if article.pictures and not simplified_view %}
      <div class="teaser_icon_container"><a href="{{ article.get_absolute_url }}">
        <img class="teaser_icon" src="{% version article.pictures.0.image.path 'small' %}" alt="{{ article.pictures.0.name }}" width="135" border="0"/>
      </a></div>
    {% endif %}

    <div class="html-content summary">
      {% if article.summary %}
        {{ article|parsed_gettext:"summary"|smart_style }}
      {% else %}
        {{ article|parsed_gettext:"text"|smart_style|truncatewords_html:40 }}
      {% endif %}
      <span class="more"><a href="{{ article.get_absolute_url }}"> {% trans "More" %}</a></span>
    </div>

    {% if not simplified_view %}
        {% include "cyclope/author_block.html"  %}
    {% endif %}

    {% if article.pictures and not simplified_view %}
    <br class="floating-img-clear" />
    {% endif %}

    {% if not simplified_view %}

    <div class="clear"></div>
    {% endif %}
  </div>
