{% extends CYCLOPE_DEFAULT_TEMPLATE %}
{% load i18n crispy_forms_tags %}

{% block content %}
  <h1 class="title">{% trans 'Reset Password' %}</h1>

  <div class="form_summary">
      <div class="summary">{% trans "Forgot your password?" %}</div>
  </div>
  <p>
      {% trans "Enter your e-mail address in the form below and we will send you a link for resetting your password." %}
  </p>
  </form>
    <form action="" method="post" class="uniForm reset_password">{% csrf_token %}
      {{form|crispy}}
      <div class="buttonHolder">
        <input type="submit" value="{% trans 'Reset Password' %}" >
      </div>
    </form>
{% endblock %}
