{% extends CYCLOPE_THEME_BASE_TEMPLATE %}
{% load layout%}
{% block title %}{%if title %}{{title}} | {%endif%}{{ CYCLOPE_SITE_SETTINGS.global_title }}{%endblock%}
{% block body_class %}four_elements{% endblock %}

{% block page_content %}
<div>{% region 'water' %}</div>
  <div class="clear"></div>
{% region 'spark' %}
  <div class="clear"></div>
<div class="container">
    <div class="clear"></div>
    <div id="fire"> {% block content %}{% endblock %}</div>
    {% region 'ash' %}
    <!-- <div class="grid_9">{% region 'love'%}</div> -->
</div>
{% endblock %}
