
  {% if page %}
  <div class="paginator">
    {% for p in page.paginator.pages %}
      {% if p == page %}
          <span class="selected">{{page}}</span>
      {% else %}
        <a href="?{% if query %}q={{ query }}&amp;{% endif %}page={{ p.number }}">{{p}}</a>
      {% endif %}
      {% if not forloop.last %}|{% endif %}
    {% endfor %}
</div>
  {% endif %}

