{% extends host_template %}

{% block content %}
<ul id="menu-{{ expand_style|lower }}-{{ menu_slug }}" class="cyclope_menu {{ expand_style|lower }}">
    {{ menu_items|unordered_list }}
</ul>
{% endblock content %}
