{% extends CYCLOPE_THEME_BASE_TEMPLATE %}

{% load layout %}

{% block body_class %}5_elements{% endblock %}

{% block page_content %}
<div class="grid_11">
<div id="fire">
    {% region 'before_fire' %}
    {% block content %}{% endblock %}
    {% region 'after_fire' %}
</div>
</div>

<div class="grid_8">
  <div class="content">
    {% region 'love'%}
  </div>
</div>

{% endblock %}
