{% extends CYCLOPE_THEME_BASE_TEMPLATE %}

{% load i18n %}
{% load layout %}

{% block title %}{% trans "Error 500 (Internal Server Error)" %}{%endblock%}

{% block body_class %}main{% endblock %}

{% block page_content %}
    {% block content %}
    <p><b>{% trans "Error 500" %}</b></p>
    <p>
      {% trans "Internal server error." %}
    </p>
    {% endblock %}

{% endblock %}
