{% extends host_template %}
{% load i18n %}

{% block content %}
<div id="map" class="content-view site map site-map">
<h2 class="title">{% trans 'Site map' %}</h2>
  <div class="menus-map">
    <ul>
      {{ menus|unordered_list }}
    </ul>
  </div>

  <div class="collection-map">
    <ul>
      {{ collections|unordered_list }}
    </ul>
  </div>

</div>
{% endblock content%}
