/*
# Cyclope 3 GPL
# Neutronix Workflow Design
# Layouts: 4 & 5 Elements
# Copyright 2010-2012 CodigoSur - SociedadCivil
# All rights reserved.
# This file is part of Cyclope 3.
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# Development: Codigo Sur www.codigosur.org
# Less CSS based www.lesscss.org
# 960 Grid System Based www.960.gs
# Neutronix is developed by Santiago Hoerth Moura
*/

/*-----------------------------------------------------------------------------------------------
960 GRID SYSTEM
-----------------------------------------------------------------------------------------------*/

body{min-width:960px}
.container_12,.container_16{margin-left:auto;margin-right:auto;width:960px}
.container_12 .grid_3,.container_16 .grid_4{width:220px}
.container_12 .grid_6,.container_16 .grid_8{width:460px}
.container_12 .grid_9,.container_16 .grid_12{width:700px}
.container_12 .grid_12,.container_16 .grid_16{width:940px}
.alpha{margin-left:0}.omega{margin-right:0}
.container_12 .grid_1{width:60px}
.container_12 .grid_2{width:140px}
.container_12 .grid_4{width:300px}
.container_12 .grid_5{width:380px}
.container_12 .grid_7{width:540px}
.container_12 .grid_8{width:620px}
.container_12 .grid_10{width:780px}
.container_12 .grid_11{width:860px}.container_16 .grid_1{width:40px}.container_16 .grid_2{width:100px}.container_16 .grid_3{width:160px}.container_16 .grid_5{width:280px}.container_16 .grid_6{width:340px}.container_16 .grid_7{width:400px}.container_16 .grid_9{width:520px}.container_16 .grid_10{width:580px}.container_16 .grid_11{width:640px}.container_16 .grid_13{width:760px}.container_16 .grid_14{width:820px}.container_16 .grid_15{width:880px}.container_12 .prefix_3,.container_16 .prefix_4{padding-left:240px}.container_12 .prefix_6,.container_16 .prefix_8{padding-left:480px}.container_12 .prefix_9,.container_16 .prefix_12{padding-left:720px}.container_12 .prefix_1{padding-left:80px}.container_12 .prefix_2{padding-left:160px}.container_12 .prefix_4{padding-left:320px}.container_12 .prefix_5{padding-left:400px}.container_12 .prefix_7{padding-left:560px}.container_12 .prefix_8{padding-left:640px}.container_12 .prefix_10{padding-left:800px}.container_12 .prefix_11{padding-left:880px}.container_16 .prefix_1{padding-left:60px}.container_16 .prefix_2{padding-left:120px}.container_16 .prefix_3{padding-left:180px}.container_16 .prefix_5{padding-left:300px}.container_16 .prefix_6{padding-left:360px}.container_16 .prefix_7{padding-left:420px}.container_16 .prefix_9{padding-left:540px}.container_16 .prefix_10{padding-left:600px}.container_16 .prefix_11{padding-left:660px}.container_16 .prefix_13{padding-left:780px}.container_16 .prefix_14{padding-left:840px}.container_16 .prefix_15{padding-left:900px}.container_12 .suffix_3,.container_16 .suffix_4{padding-right:240px}.container_12 .suffix_6,.container_16 .suffix_8{padding-right:480px}.container_12 .suffix_9,.container_16 .suffix_12{padding-right:720px}.container_12 .suffix_1{padding-right:80px}.container_12 .suffix_2{padding-right:160px}.container_12 .suffix_4{padding-right:320px}.container_12 .suffix_5{padding-right:400px}.container_12 .suffix_7{padding-right:560px}.container_12 .suffix_8{padding-right:640px}.container_12 .suffix_10{padding-right:800px}.container_12 .suffix_11{padding-right:880px}.container_16 .suffix_1{padding-right:60px}.container_16 .suffix_2{padding-right:120px}.container_16 .suffix_3{padding-right:180px}.container_16 .suffix_5{padding-right:300px}.container_16 .suffix_6{padding-right:360px}.container_16 .suffix_7{padding-right:420px}.container_16 .suffix_9{padding-right:540px}.container_16 .suffix_10{padding-right:600px}.container_16 .suffix_11{padding-right:660px}.container_16 .suffix_13{padding-right:780px}.container_16 .suffix_14{padding-right:840px}.container_16 .suffix_15{padding-right:900px}.container_12 .push_3,.container_16 .push_4{left:240px}.container_12 .push_6,.container_16 .push_8{left:480px}.container_12 .push_9,.container_16 .push_12{left:720px}.container_12 .push_1{left:80px}.container_12 .push_2{left:160px}.container_12 .push_4{left:320px}.container_12 .push_5{left:400px}.container_12 .push_7{left:560px}.container_12 .push_8{left:640px}.container_12 .push_10{left:800px}.container_12 .push_11{left:880px}.container_16 .push_1{left:60px}.container_16 .push_2{left:120px}.container_16 .push_3{left:180px}.container_16 .push_5{left:300px}.container_16 .push_6{left:360px}.container_16 .push_7{left:420px}.container_16 .push_9{left:540px}.container_16 .push_10{left:600px}.container_16 .push_11{left:660px}.container_16 .push_13{left:780px}.container_16 .push_14{left:840px}.container_16 .push_15{left:900px}.container_12 .pull_3,.container_16 .pull_4{left:-240px}.container_12 .pull_6,.container_16 .pull_8{left:-480px}.container_12 .pull_9,.container_16 .pull_12{left:-720px}.container_12 .pull_1{left:-80px}.container_12 .pull_2{left:-160px}.container_12 .pull_4{left:-320px}.container_12 .pull_5{left:-400px}.container_12 .pull_7{left:-560px}.container_12 .pull_8{left:-640px}.container_12 .pull_10{left:-800px}.container_12 .pull_11{left:-880px}.container_16 .pull_1{left:-60px}.container_16 .pull_2{left:-120px}.container_16 .pull_3{left:-180px}.container_16 .pull_5{left:-300px}.container_16 .pull_6{left:-360px}.container_16 .pull_7{left:-420px}.container_16 .pull_9{left:-540px}.container_16 .pull_10{left:-600px}.container_16 .pull_11{left:-660px}.container_16 .pull_13{left:-780px}.container_16 .pull_14{left:-840px}.container_16 .pull_15{left:-900px}.clear{clear:both;display:block;overflow:hidden;visibility:hidden;width:0;height:0}.clearfix:before,.clearfix:after,.container_12:before,.container_12:after,.container_16:before,.container_16:after{content:'.';display:block;overflow:hidden;visibility:hidden;font-size:0;line-height:0;width:0;height:0}.clearfix:after,.container_12:after,.container_16:after{clear:both}.clearfix,.container_12,.container_16{zoom:1}
.container_24{margin-left:auto;margin-right:auto;width:960px} 
.grid_1,.grid_2,.grid_3,.grid_4,.grid_5,.grid_6,.grid_7,.grid_8,.grid_9,.grid_10,.grid_11,.grid_12,.grid_13,.grid_14,.grid_15,.grid_16,.grid_17,.grid_18,.grid_19,.grid_20,.grid_21,.grid_22,.grid_23,.grid_24{display:inline;float:left;margin-left:5px;margin-right:5px}
.push_1,.pull_1,.push_2,.pull_2,.push_3,.pull_3,.push_4,.pull_4,.push_5,.pull_5,.push_6,.pull_6,.push_7,.pull_7,.push_8,.pull_8,.push_9,.pull_9,.push_10,.pull_10,.push_11,.pull_11,.push_12,.pull_12,.push_13,.pull_13,.push_14,.pull_14,.push_15,.pull_15,.push_16,.pull_16,.push_17,.pull_17,.push_18,.pull_18,.push_19,.pull_19,.push_20,.pull_20,.push_21,.pull_21,.push_22,.pull_22,.push_23,.pull_23{position:relative}
.alpha{margin-left:0}
.omega{margin-right:0}

.grid_1{width:30px}
.grid_2{width:70px}
.grid_3{width:110px} 
.grid_4{width:150px} 
.grid_5{width:190px}
.grid_6{width:230px}
.grid_7{width:270px}
.grid_8{width:310px}
.grid_9{width:350px} 
.grid_10{width:390px}
.grid_11{width:430px}
.grid_12{width:470px}
.grid_13{width:510px} 
.grid_14{width:550px}
.grid_15{width:590px}
.grid_16{width:630px}
.grid_17{width:670px}
.grid_18{width:710px} 
.grid_19{width:750px}
.grid_20{width:790px}
.grid_21{width:830px}
.grid_22{width:870px}
.grid_23{width:910px}
.grid_24{width:950px}
.prefix_1{padding-left:40px}
.prefix_2{padding-left:80px}
.prefix_3{padding-left:120px}
.prefix_4{padding-left:160px} 
.prefix_5{padding-left:200px}
.prefix_6{padding-left:240px}
.prefix_7{padding-left:280px}
.prefix_8{padding-left:320px} 
.prefix_9{padding-left:360px}
.prefix_10{padding-left:400px}
.prefix_11{padding-left:440px}
.prefix_12{padding-left:480px} 
.prefix_13{padding-left:520px}
.prefix_14{padding-left:560px} 
.prefix_15{padding-left:600px}
.prefix_16{padding-left:640px}
.prefix_17{padding-left:680px}
.prefix_18{padding-left:720px} 
.prefix_19{padding-left:760px}
.prefix_20{padding-left:800px}
.prefix_21{padding-left:840px}
.prefix_22{padding-left:880px}
.prefix_23{padding-left:920px} 
.suffix_1{padding-right:40px}
.suffix_2{padding-right:80px} 
.suffix_3{padding-right:120px}
.suffix_4{padding-right:160px}
.suffix_5{padding-right:200px}
.suffix_6{padding-right:240px}
.suffix_7{padding-right:280px}
.suffix_8{padding-right:320px} 
.suffix_9{padding-right:360px}
.suffix_10{padding-right:400px}
.suffix_11{padding-right:440px}
.suffix_12{padding-right:480px} 
.suffix_13{padding-right:520px}
.suffix_14{padding-right:560px}
.suffix_15{padding-right:600px}
.suffix_16{padding-right:640px}
.suffix_17{padding-right:680px}
.suffix_18{padding-right:720px} 
.suffix_19{padding-right:760px}
.suffix_20{padding-right:800px} 
.suffix_21{padding-right:840px}
.suffix_22{padding-right:880px}
.suffix_23{padding-right:920px}
.push_1{left:40px}
.push_2{left:80px}
.push_3{left:120px}
.push_4{left:160px}
.push_5{left:200px}  
.push_6{left:240px}
.push_7{left:280px}
.push_8{left:320px}
.push_9{left:360px}
.push_10{left:400px}
.push_11{left:440px}
.push_12{left:480px} 
.push_13{left:520px}
.push_14{left:560px}
.push_15{left:600px} 
.push_16{left:640px}
.push_17{left:680px}
.push_18{left:720px}
.push_19{left:760px} 
.push_20{left:800px}
.push_21{left:840px}
.push_22{left:880px}
.push_23{left:920px}
.pull_1{left:-40px}
.pull_2{left:-80px} 
.pull_3{left:-120px} 
.pull_4{left:-160px}
.pull_5{left:-200px}
.pull_6{left:-240px}
.pull_7{left:-280px}
.pull_8{left:-320px}
.pull_9{left:-360px}
.pull_10{left:-400px} 
.pull_11{left:-440px}
.pull_12{left:-480px} 
.pull_13{left:-520px}
.pull_14{left:-560px}
.pull_15{left:-600px}
.pull_16{left:-640px} 
.pull_17{left:-680px}
.pull_18{left:-720px} 
.pull_19{left:-760px}
.pull_20{left:-800px}
.pull_21{left:-840px}
.pull_22{left:-880px}
.pull_23{left:-920px} 
