{% load i18n threadedcomments_tags obj_perms cyclope_utils abuse %}
  {% get_comment_count for current_object as comment_count %}

  <div class="tools meta-content">
    <ul>
      <li class="first"><a href="javascript:window.print()" class="print">{% trans "Print" %}</a>
      </li>
      {% if user.is_authenticated and CYCLOPE_SITE_SETTINGS.enable_abuse_reports %}
      <li class='abuse-report'><a href="{{current_object|abuse_report_link}}">{% trans "Report abuse" %}</a></li>
      {% endif %}
      {% if current_object.allow_comments == 'YES' or current_object.allow_comments == 'SITE' and CYCLOPE_SITE_SETTINGS.allow_comments == 'YES' %}
      {% if comment_count %}
      <li>
        <a href="#comments" class="comments_link">{% trans "Comments" %} ({{ comment_count }})</a>
      </li>
      {% endif %}
      {% endif %}

      {% per_category_perms current_object as cat_perms %}
      {% if cat_perms.edit_content %}
      <li>
        <a href="/admin/{{ current_object.get_app_label }}/{{ current_object.get_object_name }}/{{current_object.pk }}?_frontend=1&_popup=1" class="edit_link">
          {% trans "Edit" %}
        </a>
      </li>
      {% endif %}
    </ul>
  </div>
