{% extends CYCLOPE_THEME_BASE_TEMPLATE %}
{% load layout %}
{% block body_class %}five_elements{% endblock %}

{% block page_content %}
<div>{% region 'water' %}</div>
  <div class="clear"></div>
 {% region 'spark' %} 
      <div class="clear"></div>
<div class="grid_15">
    <div id="fire">{% block content %}{% endblock %}</div>
    {% region 'ash' %}
</div>
<div class="grid_9">{% region 'love'%}</div>
{% endblock %}
