{% extends CYCLOPE_DEFAULT_TEMPLATE %}
{% load i18n %}

{% block title %}{% trans "Registration complete" %}.{% endblock %}

{% block content %}

<h3>{% trans "Please check your e-mail and follow the provided link in order to complete your account activation." %}.</h3>

{% endblock %}
