/*
# Cyclope 3 Workflow Design
# Theme: Neutrona 
# Layout: 5 Elements
# 960 Grid System Based www.960.gs
# Official Trac Cyclope 3 GPL: http://codigo.cyclope.ws
# Copyright 2010-2012 Codigo Sur - Sociedad Civil
# All rights reserved.
# This file is part of Cyclope 3.
# Cyclope is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# Development: Codigo Sur www.codigosur.org
# Adaptation HTML + CSS: Santiago Hoerth Moura
# Not delete this comment :)
*/

@color-alpha: #fff;
@colora: #eee6c3;
@colorb: #f7991d;
@colorc: #07b3d6;
@colord: #0d7cb9;
@colore: #e23222;
@color-omega:#000;
