{% extends "admin/base_site.html" %}
{% load i18n %}

{% block content %}
<h2>{% trans "The e-mail has been sent for newsletter " %} {{ newsletter.name }}.</h2>
<p><a href="/admin/newsletter/newsletter/{{ newsletter.id }}">{% trans "Return to newsletter admin" %}</a></p>

{% endblock %}
