/* TODO: 
 * carousel css for other regions?? #love, #water 
 * test carousel on #after_fire and #before_fire

*/

/* jcarousel for #fire region */

.jcarousel-skin-cyclope .jcarousel-container {
    -moz-border-radius: 6px;
    -webkit-border-radius: 6px;
   border-radius: 6px;
    background: #eeeeee;
    border: 2px solid #999999;
    margin-bottom: 20px;
}

.jcarousel-skin-cyclope .jcarousel-direction-rtl {
	direction: rtl;
}

.jcarousel-skin-cyclope .jcarousel-container-horizontal {
    width: 510px;
    padding: 13px 18px 60px 18px;
}

/*
.jcarousel-skin-cyclope .jcarousel-container-vertical {
}
*/

.jcarousel-skin-cyclope .jcarousel-clip {
    overflow: hidden;
    width: 510px;
    height: 330px;
}

.jcarousel-skin-cyclope .jcarousel-clip-horizontal {
}

/*
.jcarousel-skin-cyclope .jcarousel-clip-vertical {
}
*/

.jcarousel-skin-cyclope .jcarousel-item {
    width: 510px;
    height: 330px;
    padding:0;margin:0;
}

#fire .jcarousel-skin-cyclope .jcarousel-item-horizontal {
	margin-left: 0;
    margin: 0;
    margin-right: 20px;
}
/*
#fire .jcarousel-skin-cyclope .jcarousel-direction-rtl .jcarousel-item-horizontal {
    margin: 0;
	margin-left: 20px;
    margin-right: 0;
}
*/

/*
.jcarousel-skin-cyclope .jcarousel-item-vertical {
    margin-bottom: 10px;
}
*/

.jcarousel-skin-cyclope .jcarousel-item-placeholder {
    background: #fff;
    color: #000;
}

/**
 *  Horizontal Buttons
 */
.jcarousel-skin-cyclope .jcarousel-next-horizontal {
    position: absolute;
    top: 360px;
    right: 16px;
    width: 32px;
    height: 32px;
    cursor: pointer;
    background: transparent url(../images/jcarousel/next-horizontal.png) no-repeat 0 0;
}

.jcarousel-skin-cyclope .jcarousel-direction-rtl .jcarousel-next-horizontal {
    left: 5px;
    right: auto;
    background-image: url(../images/jcarousel/prev-horizontal.png);
}

.jcarousel-skin-cyclope .jcarousel-next-horizontal:hover,
.jcarousel-skin-cyclope .jcarousel-next-horizontal:focus {
    background-position: -32px 0;
}

.jcarousel-skin-cyclope .jcarousel-next-horizontal:active {
    background-position: -64px 0;
}

.jcarousel-skin-cyclope .jcarousel-next-disabled-horizontal,
.jcarousel-skin-cyclope .jcarousel-next-disabled-horizontal:hover,
.jcarousel-skin-cyclope .jcarousel-next-disabled-horizontal:focus,
.jcarousel-skin-cyclope .jcarousel-next-disabled-horizontal:active {
    cursor: default;
    background-position: -96px 0;
}

.jcarousel-skin-cyclope .jcarousel-prev-horizontal {
    position: absolute;
    top: 360px;
    left: 16px;
    width: 32px;
    height: 32px;
    cursor: pointer;
    background: transparent url(../images/jcarousel/prev-horizontal.png) no-repeat 0 0;
}

.jcarousel-skin-cyclope .jcarousel-direction-rtl .jcarousel-prev-horizontal {
    left: auto;
    right: 5px;
    background-image: url(../images/jcarousel/next-horizontal.png);
}

.jcarousel-skin-cyclope .jcarousel-prev-horizontal:hover, 
.jcarousel-skin-cyclope .jcarousel-prev-horizontal:focus {
    background-position: -32px 0;
}

.jcarousel-skin-cyclope .jcarousel-prev-horizontal:active {
    background-position: -64px 0;
}

.jcarousel-skin-cyclope .jcarousel-prev-disabled-horizontal,
.jcarousel-skin-cyclope .jcarousel-prev-disabled-horizontal:hover,
.jcarousel-skin-cyclope .jcarousel-prev-disabled-horizontal:focus,
.jcarousel-skin-cyclope .jcarousel-prev-disabled-horizontal:active {
    cursor: default;
    background-position: -96px 0;
}

/**
 *  Vertical Buttons
 */

/* not implemented in cyclope */

/*
.jcarousel-skin-cyclope .jcarousel-next-vertical {
    position: absolute;
    bottom: 5px;
    left: 43px;
    width: 32px;
    height: 32px;
    cursor: pointer;
    background: transparent url(../images/jcarousel/next-vertical.png) no-repeat 0 0;
}

.jcarousel-skin-cyclope .jcarousel-next-vertical:hover,
.jcarousel-skin-cyclope .jcarousel-next-vertical:focus {
    background-position: 0 -32px;
}

.jcarousel-skin-cyclope .jcarousel-next-vertical:active {
    background-position: 0 -64px;
}

.jcarousel-skin-cyclope .jcarousel-next-disabled-vertical,
.jcarousel-skin-cyclope .jcarousel-next-disabled-vertical:hover,
.jcarousel-skin-cyclope .jcarousel-next-disabled-vertical:focus,
.jcarousel-skin-cyclope .jcarousel-next-disabled-vertical:active {
    cursor: default;
    background-position: 0 -96px;
}

.jcarousel-skin-cyclope .jcarousel-prev-vertical {
    position: absolute;
    top: 5px;
    left: 43px;
    width: 32px;
    height: 32px;
    cursor: pointer;
    background: transparent url(../images/jcarousel/prev-vertical.png) no-repeat 0 0;
}

.jcarousel-skin-cyclope .jcarousel-prev-vertical:hover,
.jcarousel-skin-cyclope .jcarousel-prev-vertical:focus {
    background-position: 0 -32px;
}

.jcarousel-skin-cyclope .jcarousel-prev-vertical:active {
    background-position: 0 -64px;
}

.jcarousel-skin-cyclope .jcarousel-prev-disabled-vertical,
.jcarousel-skin-cyclope .jcarousel-prev-disabled-vertical:hover,
.jcarousel-skin-cyclope .jcarousel-prev-disabled-vertical:focus,
.jcarousel-skin-cyclope .jcarousel-prev-disabled-vertical:active {
    cursor: default;
    background-position: 0 -96px;
}
*/


/* internal .slideshow.teaser item styles */

#fire .slideshow.teaser {
  margin: 10px 0;
  border-bottom: none;
    padding: 0;
}

#fire .slideshow.teaser img.icon {
    border: 3px solid #CCCCCC;
    clear: both;
    float: left;
    margin: 0 20px 0 0;
    padding: 3px;
    width: 300px;
}

#fire .slideshow.teaser img.icon.big {
    border: none;
    clear: both;
    float: left;
    margin: 0;
    padding: 0;
    width: 510px;
}

#fire .slideshow.teaser img.type_icon {
    float: left;
    left: 10px;
    margin: 0;
    padding: 0 10px 0 0;
    position: absolute;
    top: 10px;
}

#fire .slideshow.teaser .teaser_icon_container {
 position: relative;
}

#fire .teaser .title {
    border: medium none;
    font-size: 1.2em;
    line-height: 1.1em;
    margin: 0;
}

#fire .slideshow.teaser .summary {
    color: #333333;
    font-size: 0.8em;
    font-weight: 400;
    line-height: 1.3em;
    padding: 0 0 15px 0;
    text-align: left;
}


