{% extends host_template %}

{% load i18n cyclope_utils fb_versions dbgettext_tags %}

{% block content %}

  {% for categorization in categorizations %}
    {% alias categorization.content_object as 'article' %}
<div class="detail">
<table>
  <tr>
    <td>
      {% if newsletter.show_ToC %}
      <span class="show-ToC"><a href="#ToC">{% trans "Return to Table of Contents" %}</a></span>
      {% endif %}
      {% if article.pretitle %} <span class="pretitle"><a name="editorial">{% trans article.pretitle %}</a></span>{% endif %}
      <a name="article__{{ article.slug }}">
        <h2 class="title">{% trans article.name  %}</h2>
      </a>
      <div class="summary content">{{ article|parsed_gettext:"summary"|smart_style }}</div>
      {% if article.author %}
      <h5 class="author">{% trans "By"%} {{ article.author }}</h5>
      {% endif %}


      <div class="text">
        {% if article.pictures %}
        <img class="newsletter_image image_content" src="{% version article.pictures.0.image.path 'small' %}" alt="{{ article.pictures.0.name }}" hspace="0" vspace="0" align="right" />
        {% endif %}

        <span class="html-text html-content">
          {{ article|parsed_gettext:"text"|smart_style}}
        </span>
      </div>
      <div class="permalink">{% trans "URL" %}: <a href="{% url article-detail article.slug %}">http://{{ CYCLOPE_SITE_SETTINGS.site.domain }}{% url article-detail article.slug %}</a></div>
    </td>
  </tr>
</table>
</div>

  {% endfor %}

{% endblock %}
