{% extends host_template %}

{% load comments i18n fb_versions cyclope_utils markup dbgettext_tags%}

{% block content %}

{% if not_allowed %}
  <h2 class="title">
      {% blocktrans %} {{ forum }} is not a forum {% endblocktrans %}
  </h2>

{% else %}

  <h1 class="title">
      {% blocktrans %} New topic in  {{ forum }} forum {% endblocktrans %}
  </h1>
<div class="create_forum">
  <form action="{{ action_url }}" method="post">{% csrf_token %}
    {{ form.as_p }}
    <input type="submit" class="submit" value="{% trans "Create" %}" />
  </form>
</div>
{% endif %}
{% endblock content%}
