{% extends CYCLOPE_DEFAULT_TEMPLATE %}
{% load i18n crispy_forms_tags %}

{% block content %}
<div class="login_form">
    <h1 class="title">{% trans "login"|capfirst %}</h1>

    <div class="form_summary">
        <div class="summary">{% trans "Please enter your credentials"%}</div>
    </div>

    <form action="." method="post" class="uniForm login">{% csrf_token %}
      {{form|crispy}}
      <div class="buttonHolder">
        <input type="submit" value="{% trans "login"|capfirst %}" />

        <span class="register">{% blocktrans %}
        If you have not yet created an account you need to
        <a href="/accounts/register?next={{next}}">register</a>
        before you may login.
        {% endblocktrans %}
        </span>
      </div>
    </form>

<script type="text/javascript">
    document.getElementById('id_username').focus()
</script>
</div>

{% endblock %}
