{% extends CYCLOPE_DEFAULT_TEMPLATE %}
{% load i18n %}

{% block title %}{% trans "Preview your comment" %}{% endblock %}

{% block content %}
<div id="user_comments">
    {% include "comments/form.html" %}
</div>
{% endblock %}
