{% extends 'collections/category_contents_base.html' %}

{% block category_content %}

{% comment %}
TODO(nicoechaniz): adapt this view to work in the same way as category_teaser_list, by providing a [content_type]_listing_view.html (or whatever better name) for every base content type, like we do with [content_type]_teaser.html
{% endcomment %}
<div class="category_root_item_list">
<ul>
{% for categorization in categorizations %}
  <li>
    <a href="/{{CYCLOPE_PREFIX}}{{ categorization.content_type.app_label }}/{{ categorization.content_type.model }}/{{ categorization.content_object.slug }}">
      <span>{{ categorization.content_object.name }}</span>
    </a>
  </li>
{% endfor %}
</ul>
</div>
{% endblock category_content %}
